<?php
/*
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2018 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

/**
 * Baum-Knoten.
 *
 * @package GhCore
 * @subpackage tree
 * @category Hilfsklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2018 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhCoreTreeNode extends GhCoreTreeBase
{
  /**
   * Baum, zu dem dieser Knoten gehört.
   * @var GhCoreTree
   */
  protected $_tree;

  /**
   * ID dieses Knotens innerhalb des Baumes.
   * @var int|string
   */
  protected $_id;

  /**
   * Eltern-Knoten.
   * @var GhCoreTreeNode
   */
  protected $_parent;

  /**
   * Titel des Knotens.
   * @var string
   */
  protected $_caption;

  /**
   * Daten des Knotens (beliebige Daten).
   * @var mixed
   */
  protected $_data;

  /**
   * Konstruktor.
   *
   * @param GhCoreTree     $tree    Baum, zu dem dieser Knoten gehört
   * @param int            $id      ID
   * @param GhCoreTreeNode $parent  Eltern-Knoten
   * @param string         $caption Titel
   * @param mixed          $data    Knoten-Daten
   */
  public function __construct($tree, $id, $parent, $caption, $data)
  {
    $this->_tree = $tree;
    $this->_id = $id;
    $this->_parent = $parent;
    $this->_caption = $caption;
    $this->_data = $data;
  }

  /**
   * Fügt diesem Knoten einen Kind-Knoten hinzu.
   *
   * @param int    $id      ID für den Kind-Knoten
   * @param string $caption Titel für den Kind-Knoten
   * @param mixed  $data    Daten für den Kind-Knoten
   * @return GhCoreTreeNode Der neu hinzugefügte Kind-Knoten
   */
  public function add($id, $caption, $data = null)
  {
    return $this->_tree->addChild($id, $this->_id, $caption, $data);
  }

  /**
   * Liefert die ID dieses Knotens.
   *
   * @return int|string ID
   */
  public function getId()
  {
    return $this->_id;
  }

  /**
   * Liefert den Eltern-Knoten dieses Knotens.
   *
   * @return GhCoreTreeNode Eltern-Knoten
   */
  public function getParent()
  {
    return $this->_parent;
  }

  /**
   * Setzt den Eltern-Knoten dieses Knotens.
   *
   * @return void
   */
  public function setParent($parent)
  {
    $this->_parent = $parent;
  }

  /**
   * Liefert den Titel dieses Knotens.
   *
   * @return string Titel
   */
  public function getCaption()
  {
    return $this->_caption;
  }

  /**
   * Setzt den Titel dieses Knotens.
   *
   * @param string $value Titel
   */
  public function setCaption($value)
  {
    $this->_caption = $value;
  }

  /**
   * Liefert die Daten dieses Knotens.
   *
   * @return mixed Daten
   */
  public function getData()
  {
    return $this->_data;
  }

  /**
   * Setzt die Daten für diesen Knoten.
   * Dies können beliebige Daten (eines beliebigen Typs) sein.
   *
   * @param mixed $value Daten
   */
  public function setData($value)
  {
    $this->_data = $value;
  }
}