<?php
/*
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2018 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

/**
 * Klasse für RPC-Fault Ergebnisse.
 *
 * @package GhRpc
 * @subpackage core
 * @category PHP-RPC-Kernklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2018 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcFault extends GhRpcStruct
{
  /**
   * Fehlercode.
   * @var int
   */
  public $faultCode;

  /**
   * Fehlerbeschreibung.
   * @var string
   */
  public $faultString;

  /**
   * Eigenschaften (Schlüssel) und Datentypen (Werte) des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'faultCode' => 'int',
    'faultString' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Datentyp einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Eigenschaft (ohne $-Zeichen)
   * @return string Datentyp
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}