<?php
/**
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2018 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */


/**
 * RPC-Unit rpc_asplib.
 *
 * @package GhRpc
 * @subpackage rpc_asplib
 * @category PHP-RPC-Units
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2018 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class rpc_asplib extends GhRpcLibrary
{
  // RpcStatusFlag Konstanten:

  /**
   * sfRunning Konstante (gehört zum Enum: RpcStatusFlag).
   */
  const sfRunning = 0;
  /**
   * sfStopped Konstante (gehört zum Enum: RpcStatusFlag).
   */
  const sfStopped = 1;
  /**
   * sfFailure Konstante (gehört zum Enum: RpcStatusFlag).
   */
  const sfFailure = 2;

  // RpcFaxDirection Konstanten:

  /**
   * fdIncoming Konstante (gehört zum Enum: RpcFaxDirection).
   */
  const fdIncoming = 0;
  /**
   * fdOutgoing Konstante (gehört zum Enum: RpcFaxDirection).
   */
  const fdOutgoing = 1;

  // RpcFaxState Konstanten:

  /**
   * fsOk Konstante (gehört zum Enum: RpcFaxState).
   */
  const fsOk = 0;
  /**
   * fsError Konstante (gehört zum Enum: RpcFaxState).
   */
  const fsError = 1;

  /**
   * Hilfskonstante, die ein Set darstellt, in dem alle Enums gesetzt sind.
   * @var int
   */
  const SET_ALL = -1;


  /**
   * Erzeugt eine Instanz des RPC-Dienstes RpcAsp.
   *
   * @param GhRpcClient $client Client Instanz
   *
   * @return GhRpcAsplibRpcAsp
   */
  public static function newRpcAsp(GhRpcClient $client)
  {
    return new GhRpcAsplibRpcAsp($client);
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcServerStatus.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcAsplibRpcServerStatus
   */
  public static function newRpcServerStatus($fillProperties = false)
  {
    $object = new GhRpcAsplibRpcServerStatus();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcFaxJournal.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcAsplibRpcFaxJournal
   */
  public static function newRpcFaxJournal($fillProperties = false)
  {
    $object = new GhRpcAsplibRpcFaxJournal();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcServerInfo.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcAsplibRpcServerInfo
   */
  public static function newRpcServerInfo($fillProperties = false)
  {
    $object = new GhRpcAsplibRpcServerInfo();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }
}


/**
 * RPC-Struct RpcFaxJournalList.
 *
 * @package GhRpc
 * @subpackage rpc_asplib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2018 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcAsplibRpcServerInfo extends GhRpcStruct
{
  /**
   * OnlineSince
   * @var GhRpcDateTime
   */
  public $OnlineSince;

  /**
   * ServerTime
   * @var GhRpcDateTime
   */
  public $ServerTime;

  /**
   * Version
   * @var string
   */
  public $Version;

  /**
   * Connections
   * @var int
   */
  public $Connections;

  /**
   * MaxConnections
   * @var int
   */
  public $MaxConnections;

  /**
   * HttpPort
   * @var int
   */
  public $HttpPort;

  /**
   * RpcpPort
   * @var int
   */
  public $RpcpPort;

  /**
   * KeepAlive
   * @var boolean
   */
  public $KeepAlive;

  /**
   * Compress
   * @var boolean
   */
  public $Compress;

  /**
   * UseRpcps
   * @var boolean
   */
  public $UseRpcps;

  /**
   * UseSSL
   * @var boolean
   */
  public $UseSSL;

  /**
   * MethodCount
   * @var int
   */
  public $MethodCount;

  /**
   * Win32ClientVersion
   * @var string
   */
  public $Win32ClientVersion;

  /**
   * CPU
   * @var string
   */
  public $CPU;

  /**
   * CPUUsage
   * @var int
   */
  public $CPUUsage;

  /**
   * OS
   * @var string
   */
  public $OS;

  /**
   * TotalPhysicalMemory
   * @var GhRpcInt64
   */
  public $TotalPhysicalMemory;

  /**
   * AvailablePhysicalMemory
   * @var GhRpcInt64
   */
  public $AvailablePhysicalMemory;

  /**
   * TotalVirtualMemory
   * @var GhRpcInt64
   */
  public $TotalVirtualMemory;

  /**
   * AvailableVirtualMemory
   * @var GhRpcInt64
   */
  public $AvailableVirtualMemory;

  /**
   * DatabaseSize
   * @var GhRpcInt64
   */
  public $DatabaseSize;

  /**
   * Hostname
   * @var string
   */
  public $Hostname;

  /**
   * IPAddress
   * @var string
   */
  public $IPAddress;

  /**
   * DiskSize
   * @var GhRpcInt64
   */
  public $DiskSize;

  /**
   * DiskFree
   * @var GhRpcInt64
   */
  public $DiskFree;

  /**
   * ServerTimeZone
   * @var string
   */
  public $ServerTimeZone;

  /**
   * BiggestDatabaseTableSize
   * @var GhRpcInt64
   */
  public $BiggestDatabaseTableSize;

  /**
   * PublicHost
   * @var string
   */
  public $PublicHost;

  /**
   * ContractNumber
   * @var string
   */
  public $ContractNumber;

  /**
   * Serial
   * @var string
   */
  public $Serial;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'OnlineSince' => 'GhRpcDateTime',
    'ServerTime' => 'GhRpcDateTime',
    'Version' => 'string',
    'Connections' => 'int',
    'MaxConnections' => 'int',
    'HttpPort' => 'int',
    'RpcpPort' => 'int',
    'KeepAlive' => 'boolean',
    'Compress' => 'boolean',
    'UseRpcps' => 'boolean',
    'UseSSL' => 'boolean',
    'MethodCount' => 'int',
    'Win32ClientVersion' => 'string',
    'CPU' => 'string',
    'CPUUsage' => 'int',
    'OS' => 'string',
    'TotalPhysicalMemory' => 'GhRpcInt64',
    'AvailablePhysicalMemory' => 'GhRpcInt64',
    'TotalVirtualMemory' => 'GhRpcInt64',
    'AvailableVirtualMemory' => 'GhRpcInt64',
    'DatabaseSize' => 'GhRpcInt64',
    'Hostname' => 'string',
    'IPAddress' => 'string',
    'DiskSize' => 'GhRpcInt64',
    'DiskFree' => 'GhRpcInt64',
    'ServerTimeZone' => 'string',
    'BiggestDatabaseTableSize' => 'GhRpcInt64',
    'PublicHost' => 'string',
    'ContractNumber' => 'string',
    'Serial' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcFaxJournalList.
 *
 * @package GhRpc
 * @subpackage rpc_asplib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2018 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcAsplibRpcFaxJournal extends GhRpcStruct
{
  /**
   * State
   * @var int
   */
  public $State;

  /**
   * Direction
   * @var int
   */
  public $Direction;

  /**
   * StartDate
   * @var GhRpcDateTime
   */
  public $StartDate;

  /**
   * EndDate
   * @var GhRpcDateTime
   */
  public $EndDate;

  /**
   * CallingNumber
   * @var string
   */
  public $CallingNumber;

  /**
   * CalledNumber
   * @var string
   */
  public $CalledNumber;

  /**
   * Pages
   * @var int
   */
  public $Pages;

  /**
   * TryCount
   * @var int
   */
  public $TryCount;

  /**
   * Text
   * @var string
   */
  public $Text;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'State' => 'int',
    'Direction' => 'int',
    'StartDate' => 'GhRpcDateTime',
    'EndDate' => 'GhRpcDateTime',
    'CallingNumber' => 'string',
    'CalledNumber' => 'string',
    'Pages' => 'int',
    'TryCount' => 'int',
    'Text' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcFaxJournalList.
 *
 * @package GhRpc
 * @subpackage rpc_asplib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2018 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcAsplibRpcServerStatus extends GhRpcStruct
{
  /**
   * MySqlServer
   * @var int
   */
  public $MySqlServer;

  /**
   * AppServer
   * @var int
   */
  public $AppServer;

  /**
   * QueueServer
   * @var int
   */
  public $QueueServer;

  /**
   * CommServer
   * @var int
   */
  public $CommServer;

  /**
   * GatewayServer
   * @var int
   */
  public $GatewayServer;

  /**
   * AccessServer
   * @var int
   */
  public $AccessServer;

  /**
   * SyncServer
   * @var int
   */
  public $SyncServer;

  /**
   * CommServerLastAction
   * @var string
   */
  public $CommServerLastAction;

  /**
   * QueueServerLastAction
   * @var string
   */
  public $QueueServerLastAction;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'MySqlServer' => 'int',
    'AppServer' => 'int',
    'QueueServer' => 'int',
    'CommServer' => 'int',
    'GatewayServer' => 'int',
    'AccessServer' => 'int',
    'SyncServer' => 'int',
    'CommServerLastAction' => 'string',
    'QueueServerLastAction' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Dienst RpcAsp
 *
 * @package GhRpc
 * @subpackage rpc_asplib
 * @category PHP-RPC-Dienste
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2018 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcAsplibRpcAsp extends GhRpcService
{
  /**
   * RPC-Methoden mit Parametern und Ergebnistypen.
   * @var array
   */
  protected static $_rpcMethods = array(
    'Update' => array(
      'params' => array(
        'ContractNumber' => 'string',
        'SerialNumber' => 'string',
      ),
      'return' => '',
    ),
    'Restart' => array(
      'params' => array(
      ),
      'return' => '',
    ),
    'Shutdown' => array(
      'params' => array(
      ),
      'return' => '',
    ),
    'Optimize' => array(
      'params' => array(
      ),
      'return' => '',
    ),
    'Stop' => array(
      'params' => array(
      ),
      'return' => '',
    ),
    'Start' => array(
      'params' => array(
      ),
      'return' => '',
    ),
    'IsServerRunning' => array(
      'params' => array(
      ),
      'return' => 'boolean',
    ),
    'IsActionRunning' => array(
      'params' => array(
      ),
      'return' => 'boolean',
    ),
    'IsInstalled' => array(
      'params' => array(
      ),
      'return' => 'boolean',
    ),
    'UpdateLogin' => array(
      'params' => array(
        'Username' => 'string',
        'Password' => 'string',
      ),
      'return' => '',
    ),
    'UpdatePublicHost' => array(
      'params' => array(
        'PublicHost' => 'string',
      ),
      'return' => '',
    ),
    'UpdateSSLRoot' => array(
      'params' => array(
        'Crt' => 'string',
        'Key' => 'string',
        'RootCrt' => 'string',
        'Password' => 'string',
      ),
      'return' => '',
    ),
    'UpdateSSL' => array(
      'params' => array(
        'Crt' => 'string',
        'Key' => 'string',
        'Password' => 'string',
      ),
      'return' => '',
    ),
    'UpdateSerial' => array(
      'params' => array(
        'SerialNumber' => 'string',
      ),
      'return' => '',
    ),
    'GetFaxJournal' => array(
      'params' => array(
        'Number' => 'string',
        'StartDate' => 'GhRpcDateTime',
      ),
      'return' => 'array:GhRpcAsplibRpcFaxJournal',
    ),
    'DeleteFaxAccount' => array(
      'params' => array(
        'Number' => 'string',
      ),
      'return' => '',
    ),
    'AddFaxAccount' => array(
      'params' => array(
        'Name' => 'string',
        'Number' => 'string',
        'Password' => 'string',
      ),
      'return' => '',
    ),
    'Uninstall' => array(
      'params' => array(
      ),
      'return' => '',
    ),
    'Install' => array(
      'params' => array(
        'ContractNumber' => 'string',
        'SerialNumber' => 'string',
        'Language' => 'string',
        'AdminPassword' => 'string',
        'DatabaseTemplate' => 'string',
      ),
      'return' => '',
    ),
    'GetServerStatus' => array(
      'params' => array(
      ),
      'return' => 'GhRpcAsplibRpcServerStatus',
    ),
    'GetServerInfo' => array(
      'params' => array(
      ),
      'return' => 'GhRpcAsplibRpcServerInfo',
    ),
  );


  /**
   * Ruft die RPC-Funktion RpcAsp.GetServerInfo auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return GhRpcAsplibRpcServerInfo
   */
  public function GetServerInfo()
  {
    return $this->_sendRpcRequest('RpcAsp.GetServerInfo', array(), self::$_rpcMethods['GetServerInfo']);
  }

  /**
   * Ruft die RPC-Funktion RpcAsp.GetServerStatus auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return GhRpcAsplibRpcServerStatus
   */
  public function GetServerStatus()
  {
    return $this->_sendRpcRequest('RpcAsp.GetServerStatus', array(), self::$_rpcMethods['GetServerStatus']);
  }

  /**
   * Ruft die RPC-Funktion RpcAsp.Install auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $ContractNumber
   * @param string $SerialNumber
   * @param string $Language
   * @param string $AdminPassword
   * @param string $DatabaseTemplate
   */
  public function Install($ContractNumber, $SerialNumber, $Language, $AdminPassword, $DatabaseTemplate)
  {
    return $this->_sendRpcRequest('RpcAsp.Install', array($ContractNumber, $SerialNumber, $Language, $AdminPassword, $DatabaseTemplate), self::$_rpcMethods['Install']);
  }

  /**
   * Ruft die RPC-Funktion RpcAsp.Uninstall auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   */
  public function Uninstall()
  {
    return $this->_sendRpcRequest('RpcAsp.Uninstall', array(), self::$_rpcMethods['Uninstall']);
  }

  /**
   * Ruft die RPC-Funktion RpcAsp.AddFaxAccount auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Name
   * @param string $Number
   * @param string $Password
   */
  public function AddFaxAccount($Name, $Number, $Password)
  {
    return $this->_sendRpcRequest('RpcAsp.AddFaxAccount', array($Name, $Number, $Password), self::$_rpcMethods['AddFaxAccount']);
  }

  /**
   * Ruft die RPC-Funktion RpcAsp.DeleteFaxAccount auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Number
   */
  public function DeleteFaxAccount($Number)
  {
    return $this->_sendRpcRequest('RpcAsp.DeleteFaxAccount', array($Number), self::$_rpcMethods['DeleteFaxAccount']);
  }

  /**
   * Ruft die RPC-Funktion RpcAsp.GetFaxJournal auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Number
   * @param GhRpcDateTime $StartDate
   *
   * @return array
   */
  public function GetFaxJournal($Number, GhRpcDateTime $StartDate)
  {
    return $this->_sendRpcRequest('RpcAsp.GetFaxJournal', array($Number, $StartDate), self::$_rpcMethods['GetFaxJournal']);
  }

  /**
   * Ruft die RPC-Funktion RpcAsp.UpdateSerial auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $SerialNumber
   */
  public function UpdateSerial($SerialNumber)
  {
    return $this->_sendRpcRequest('RpcAsp.UpdateSerial', array($SerialNumber), self::$_rpcMethods['UpdateSerial']);
  }

  /**
   * Ruft die RPC-Funktion RpcAsp.UpdateSSL auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Crt
   * @param string $Key
   * @param string $Password
   */
  public function UpdateSSL($Crt, $Key, $Password)
  {
    return $this->_sendRpcRequest('RpcAsp.UpdateSSL', array($Crt, $Key, $Password), self::$_rpcMethods['UpdateSSL']);
  }

  /**
   * Ruft die RPC-Funktion RpcAsp.UpdateSSLRoot auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Crt
   * @param string $Key
   * @param string $RootCrt
   * @param string $Password
   */
  public function UpdateSSLRoot($Crt, $Key, $RootCrt, $Password)
  {
    return $this->_sendRpcRequest('RpcAsp.UpdateSSLRoot', array($Crt, $Key, $RootCrt, $Password), self::$_rpcMethods['UpdateSSLRoot']);
  }

  /**
   * Ruft die RPC-Funktion RpcAsp.UpdatePublicHost auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $PublicHost
   */
  public function UpdatePublicHost($PublicHost)
  {
    return $this->_sendRpcRequest('RpcAsp.UpdatePublicHost', array($PublicHost), self::$_rpcMethods['UpdatePublicHost']);
  }

  /**
   * Ruft die RPC-Funktion RpcAsp.UpdateLogin auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Username
   * @param string $Password
   */
  public function UpdateLogin($Username, $Password)
  {
    return $this->_sendRpcRequest('RpcAsp.UpdateLogin', array($Username, $Password), self::$_rpcMethods['UpdateLogin']);
  }

  /**
   * Ruft die RPC-Funktion RpcAsp.IsInstalled auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return boolean
   */
  public function IsInstalled()
  {
    return $this->_sendRpcRequest('RpcAsp.IsInstalled', array(), self::$_rpcMethods['IsInstalled']);
  }

  /**
   * Ruft die RPC-Funktion RpcAsp.IsActionRunning auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return boolean
   */
  public function IsActionRunning()
  {
    return $this->_sendRpcRequest('RpcAsp.IsActionRunning', array(), self::$_rpcMethods['IsActionRunning']);
  }

  /**
   * Ruft die RPC-Funktion RpcAsp.IsServerRunning auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return boolean
   */
  public function IsServerRunning()
  {
    return $this->_sendRpcRequest('RpcAsp.IsServerRunning', array(), self::$_rpcMethods['IsServerRunning']);
  }

  /**
   * Ruft die RPC-Funktion RpcAsp.Start auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   */
  public function Start()
  {
    return $this->_sendRpcRequest('RpcAsp.Start', array(), self::$_rpcMethods['Start']);
  }

  /**
   * Ruft die RPC-Funktion RpcAsp.Stop auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   */
  public function Stop()
  {
    return $this->_sendRpcRequest('RpcAsp.Stop', array(), self::$_rpcMethods['Stop']);
  }

  /**
   * Ruft die RPC-Funktion RpcAsp.Optimize auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   */
  public function Optimize()
  {
    return $this->_sendRpcRequest('RpcAsp.Optimize', array(), self::$_rpcMethods['Optimize']);
  }

  /**
   * Ruft die RPC-Funktion RpcAsp.Shutdown auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   */
  public function Shutdown()
  {
    return $this->_sendRpcRequest('RpcAsp.Shutdown', array(), self::$_rpcMethods['Shutdown']);
  }

  /**
   * Ruft die RPC-Funktion RpcAsp.Restart auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   */
  public function Restart()
  {
    return $this->_sendRpcRequest('RpcAsp.Restart', array(), self::$_rpcMethods['Restart']);
  }

  /**
   * Ruft die RPC-Funktion RpcAsp.Update auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $ContractNumber
   * @param string $SerialNumber
   */
  public function Update($ContractNumber, $SerialNumber)
  {
    return $this->_sendRpcRequest('RpcAsp.Update', array($ContractNumber, $SerialNumber), self::$_rpcMethods['Update']);
  }
}
