<?php
/**
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2017 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */


/**
 * RPC-Unit rpc_categorieslib.
 *
 * @package GhRpc
 * @subpackage rpc_categorieslib
 * @category PHP-RPC-Units
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class rpc_categorieslib extends GhRpcLibrary
{
  // RpcLockState Konstanten:

  /**
   * lsUnlocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsUnlocked = 0;
  /**
   * lsModified Konstante (gehört zum Enum: RpcLockState).
   */
  const lsModified = 1;
  /**
   * lsLocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsLocked = 2;

  /**
   * Hilfskonstante, die ein Set darstellt, in dem alle Enums gesetzt sind.
   * @var int
   */
  const SET_ALL = -1;


  /**
   * Erzeugt eine Instanz des RPC-Dienstes RpcCategories.
   *
   * @param GhRpcClient $client Client Instanz
   *
   * @return GhRpcCategorieslibRpcCategories
   */
  public static function newRpcCategories(GhRpcClient $client)
  {
    return new GhRpcCategorieslibRpcCategories($client);
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcLockData.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcCategorieslibRpcLockData
   */
  public static function newRpcLockData($fillProperties = false)
  {
    $object = new GhRpcCategorieslibRpcLockData();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcCategory.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcCategorieslibRpcCategory
   */
  public static function newRpcCategory($fillProperties = false)
  {
    $object = new GhRpcCategorieslibRpcCategory();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }
}


/**
 * RPC-Struct RpcCategoryList.
 *
 * @package GhRpc
 * @subpackage rpc_categorieslib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcCategorieslibRpcCategory extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * FilterRefs
   * @var array
   */
  public $FilterRefs;

  /**
   * GroupRefs
   * @var array
   */
  public $GroupRefs;

  /**
   * UserRefs
   * @var array
   */
  public $UserRefs;

  /**
   * TopicRefs
   * @var array
   */
  public $TopicRefs;

  /**
   * ColorRefs
   * @var array
   */
  public $ColorRefs;

  /**
   * TextBlockRefs
   * @var array
   */
  public $TextBlockRefs;

  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * LockData
   * @var GhRpcCategorieslibRpcLockData
   */
  public $LockData;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'FilterRefs' => 'array:int',
    'GroupRefs' => 'array:int',
    'UserRefs' => 'array:int',
    'TopicRefs' => 'array:int',
    'ColorRefs' => 'array:int',
    'TextBlockRefs' => 'array:int',
    'Name' => 'string',
    'LockData' => 'GhRpcCategorieslibRpcLockData',
    'Created' => 'GhRpcDateTime',
    'Modified' => 'GhRpcDateTime',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcCategoryList.
 *
 * @package GhRpc
 * @subpackage rpc_categorieslib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcCategorieslibRpcLockData extends GhRpcStruct
{
  /**
   * LockState
   * @var int
   */
  public $LockState;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * UserName
   * @var string
   */
  public $UserName;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'LockState' => 'int',
    'UserRef' => 'int',
    'UserName' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Dienst RpcCategories
 *
 * @package GhRpc
 * @subpackage rpc_categorieslib
 * @category PHP-RPC-Dienste
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcCategorieslibRpcCategories extends GhRpcService
{
  /**
   * RPC-Methoden mit Parametern und Ergebnistypen.
   * @var array
   */
  protected static $_rpcMethods = array(
    'GetLockData' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcCategorieslibRpcLockData',
    ),
    'Unlock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Lock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'AddTextBlock' => array(
      'params' => array(
        'ID' => 'int',
        'TextBlockRef' => 'int',
      ),
      'return' => '',
    ),
    'AddColor' => array(
      'params' => array(
        'ID' => 'int',
        'ColorRef' => 'int',
      ),
      'return' => '',
    ),
    'AddTopic' => array(
      'params' => array(
        'ID' => 'int',
        'TopicRef' => 'int',
      ),
      'return' => '',
    ),
    'AddUser' => array(
      'params' => array(
        'ID' => 'int',
        'UserRef' => 'int',
      ),
      'return' => '',
    ),
    'AddGroup' => array(
      'params' => array(
        'ID' => 'int',
        'GroupRef' => 'int',
      ),
      'return' => '',
    ),
    'AddFilter' => array(
      'params' => array(
        'ID' => 'int',
        'FilterRef' => 'int',
      ),
      'return' => '',
    ),
    'Delete' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Put' => array(
      'params' => array(
        'Category' => 'GhRpcCategorieslibRpcCategory',
      ),
      'return' => '',
    ),
    'New_' => array(
      'params' => array(
        'Category' => 'GhRpcCategorieslibRpcCategory',
      ),
      'return' => 'int',
    ),
    'GetList' => array(
      'params' => array(
        'AdvancedFields' => 'boolean',
      ),
      'return' => 'array:GhRpcCategorieslibRpcCategory',
    ),
    'Get' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcCategorieslibRpcCategory',
    ),
  );


  /**
   * Ruft die RPC-Funktion RpcCategories.Get auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcCategorieslibRpcCategory
   */
  public function Get($ID)
  {
    return $this->_sendRpcRequest('RpcCategories.Get', array($ID), self::$_rpcMethods['Get']);
  }

  /**
   * Ruft die RPC-Funktion RpcCategories.GetList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param boolean $AdvancedFields
   *
   * @return array
   */
  public function GetList($AdvancedFields)
  {
    return $this->_sendRpcRequest('RpcCategories.GetList', array($AdvancedFields), self::$_rpcMethods['GetList']);
  }

  /**
   * Ruft die RPC-Funktion RpcCategories.New auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcCategorieslibRpcCategory $Category
   *
   * @return int
   */
  public function New_(GhRpcCategorieslibRpcCategory $Category)
  {
    return $this->_sendRpcRequest('RpcCategories.New', array($Category), self::$_rpcMethods['New_']);
  }

  /**
   * Ruft die RPC-Funktion RpcCategories.Put auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcCategorieslibRpcCategory $Category
   */
  public function Put(GhRpcCategorieslibRpcCategory $Category)
  {
    return $this->_sendRpcRequest('RpcCategories.Put', array($Category), self::$_rpcMethods['Put']);
  }

  /**
   * Ruft die RPC-Funktion RpcCategories.Delete auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Delete($ID)
  {
    return $this->_sendRpcRequest('RpcCategories.Delete', array($ID), self::$_rpcMethods['Delete']);
  }

  /**
   * Ruft die RPC-Funktion RpcCategories.AddFilter auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $FilterRef
   */
  public function AddFilter($ID, $FilterRef)
  {
    return $this->_sendRpcRequest('RpcCategories.AddFilter', array($ID, $FilterRef), self::$_rpcMethods['AddFilter']);
  }

  /**
   * Ruft die RPC-Funktion RpcCategories.AddGroup auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $GroupRef
   */
  public function AddGroup($ID, $GroupRef)
  {
    return $this->_sendRpcRequest('RpcCategories.AddGroup', array($ID, $GroupRef), self::$_rpcMethods['AddGroup']);
  }

  /**
   * Ruft die RPC-Funktion RpcCategories.AddUser auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $UserRef
   */
  public function AddUser($ID, $UserRef)
  {
    return $this->_sendRpcRequest('RpcCategories.AddUser', array($ID, $UserRef), self::$_rpcMethods['AddUser']);
  }

  /**
   * Ruft die RPC-Funktion RpcCategories.AddTopic auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $TopicRef
   */
  public function AddTopic($ID, $TopicRef)
  {
    return $this->_sendRpcRequest('RpcCategories.AddTopic', array($ID, $TopicRef), self::$_rpcMethods['AddTopic']);
  }

  /**
   * Ruft die RPC-Funktion RpcCategories.AddColor auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $ColorRef
   */
  public function AddColor($ID, $ColorRef)
  {
    return $this->_sendRpcRequest('RpcCategories.AddColor', array($ID, $ColorRef), self::$_rpcMethods['AddColor']);
  }

  /**
   * Ruft die RPC-Funktion RpcCategories.AddTextBlock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $TextBlockRef
   */
  public function AddTextBlock($ID, $TextBlockRef)
  {
    return $this->_sendRpcRequest('RpcCategories.AddTextBlock', array($ID, $TextBlockRef), self::$_rpcMethods['AddTextBlock']);
  }

  /**
   * Ruft die RPC-Funktion RpcCategories.Lock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Lock($ID)
  {
    return $this->_sendRpcRequest('RpcCategories.Lock', array($ID), self::$_rpcMethods['Lock']);
  }

  /**
   * Ruft die RPC-Funktion RpcCategories.Unlock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Unlock($ID)
  {
    return $this->_sendRpcRequest('RpcCategories.Unlock', array($ID), self::$_rpcMethods['Unlock']);
  }

  /**
   * Ruft die RPC-Funktion RpcCategories.GetLockData auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcCategorieslibRpcLockData
   */
  public function GetLockData($ID)
  {
    return $this->_sendRpcRequest('RpcCategories.GetLockData', array($ID), self::$_rpcMethods['GetLockData']);
  }
}
