<?php
/**
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2017 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */


/**
 * RPC-Unit rpc_citieslib.
 *
 * @package GhRpc
 * @subpackage rpc_citieslib
 * @category PHP-RPC-Units
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class rpc_citieslib extends GhRpcLibrary
{
  // RpcLockState Konstanten:

  /**
   * lsUnlocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsUnlocked = 0;
  /**
   * lsModified Konstante (gehört zum Enum: RpcLockState).
   */
  const lsModified = 1;
  /**
   * lsLocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsLocked = 2;

  // RpcCityOrderDirection Konstanten:

  /**
   * codAscending Konstante (gehört zum Enum: RpcCityOrderDirection).
   */
  const codAscending = 0;
  /**
   * codDescending Konstante (gehört zum Enum: RpcCityOrderDirection).
   */
  const codDescending = 1;

  // RpcCityOrderBy Konstanten:

  /**
   * cobCountryRef Konstante (gehört zum Enum: RpcCityOrderBy).
   */
  const cobCountryRef = 0;
  /**
   * cobName Konstante (gehört zum Enum: RpcCityOrderBy).
   */
  const cobName = 1;
  /**
   * cobZip Konstante (gehört zum Enum: RpcCityOrderBy).
   */
  const cobZip = 2;
  /**
   * cobPrefix Konstante (gehört zum Enum: RpcCityOrderBy).
   */
  const cobPrefix = 3;
  /**
   * cobCreated Konstante (gehört zum Enum: RpcCityOrderBy).
   */
  const cobCreated = 4;
  /**
   * cobModified Konstante (gehört zum Enum: RpcCityOrderBy).
   */
  const cobModified = 5;

  /**
   * Hilfskonstante, die ein Set darstellt, in dem alle Enums gesetzt sind.
   * @var int
   */
  const SET_ALL = -1;


  /**
   * Erzeugt eine Instanz des RPC-Dienstes RpcCities.
   *
   * @param GhRpcClient $client Client Instanz
   *
   * @return GhRpcCitieslibRpcCities
   */
  public static function newRpcCities(GhRpcClient $client)
  {
    return new GhRpcCitieslibRpcCities($client);
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcLockData.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcCitieslibRpcLockData
   */
  public static function newRpcLockData($fillProperties = false)
  {
    $object = new GhRpcCitieslibRpcLockData();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcCity.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcCitieslibRpcCity
   */
  public static function newRpcCity($fillProperties = false)
  {
    $object = new GhRpcCitieslibRpcCity();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }
}


/**
 * RPC-Struct RpcCityList.
 *
 * @package GhRpc
 * @subpackage rpc_citieslib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcCitieslibRpcCity extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * CountryRef
   * @var int
   */
  public $CountryRef;

  /**
   * CountryName
   * @var string
   */
  public $CountryName;

  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * Zip
   * @var string
   */
  public $Zip;

  /**
   * Prefix
   * @var string
   */
  public $Prefix;

  /**
   * LockData
   * @var GhRpcCitieslibRpcLockData
   */
  public $LockData;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'CountryRef' => 'int',
    'CountryName' => 'string',
    'Name' => 'string',
    'Zip' => 'string',
    'Prefix' => 'string',
    'LockData' => 'GhRpcCitieslibRpcLockData',
    'Created' => 'GhRpcDateTime',
    'Modified' => 'GhRpcDateTime',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcCityList.
 *
 * @package GhRpc
 * @subpackage rpc_citieslib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcCitieslibRpcLockData extends GhRpcStruct
{
  /**
   * LockState
   * @var int
   */
  public $LockState;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * UserName
   * @var string
   */
  public $UserName;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'LockState' => 'int',
    'UserRef' => 'int',
    'UserName' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Dienst RpcCities
 *
 * @package GhRpc
 * @subpackage rpc_citieslib
 * @category PHP-RPC-Dienste
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcCitieslibRpcCities extends GhRpcService
{
  /**
   * RPC-Methoden mit Parametern und Ergebnistypen.
   * @var array
   */
  protected static $_rpcMethods = array(
    'GetLockData' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcCitieslibRpcLockData',
    ),
    'Unlock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Lock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Delete' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Put' => array(
      'params' => array(
        'City' => 'GhRpcCitieslibRpcCity',
      ),
      'return' => '',
    ),
    'New_' => array(
      'params' => array(
        'City' => 'GhRpcCitieslibRpcCity',
      ),
      'return' => 'int',
    ),
    'GetList' => array(
      'params' => array(
        'FilterValue' => 'string',
        'CountryRef' => 'int',
        'Offset' => 'int',
        'OrderBy' => 'int',
        'OrderDirection' => 'int',
      ),
      'return' => 'array:GhRpcCitieslibRpcCity',
    ),
    'Get' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcCitieslibRpcCity',
    ),
  );


  /**
   * Ruft die RPC-Funktion RpcCities.Get auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcCitieslibRpcCity
   */
  public function Get($ID)
  {
    return $this->_sendRpcRequest('RpcCities.Get', array($ID), self::$_rpcMethods['Get']);
  }

  /**
   * Ruft die RPC-Funktion RpcCities.GetList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $FilterValue
   * @param int $CountryRef
   * @param int $Offset
   * @param int $OrderBy
   * @param int $OrderDirection
   *
   * @return array
   */
  public function GetList($FilterValue, $CountryRef, $Offset, $OrderBy, $OrderDirection)
  {
    return $this->_sendRpcRequest('RpcCities.GetList', array($FilterValue, $CountryRef, $Offset, $OrderBy, $OrderDirection), self::$_rpcMethods['GetList']);
  }

  /**
   * Ruft die RPC-Funktion RpcCities.New auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcCitieslibRpcCity $City
   *
   * @return int
   */
  public function New_(GhRpcCitieslibRpcCity $City)
  {
    return $this->_sendRpcRequest('RpcCities.New', array($City), self::$_rpcMethods['New_']);
  }

  /**
   * Ruft die RPC-Funktion RpcCities.Put auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcCitieslibRpcCity $City
   */
  public function Put(GhRpcCitieslibRpcCity $City)
  {
    return $this->_sendRpcRequest('RpcCities.Put', array($City), self::$_rpcMethods['Put']);
  }

  /**
   * Ruft die RPC-Funktion RpcCities.Delete auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Delete($ID)
  {
    return $this->_sendRpcRequest('RpcCities.Delete', array($ID), self::$_rpcMethods['Delete']);
  }

  /**
   * Ruft die RPC-Funktion RpcCities.Lock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Lock($ID)
  {
    return $this->_sendRpcRequest('RpcCities.Lock', array($ID), self::$_rpcMethods['Lock']);
  }

  /**
   * Ruft die RPC-Funktion RpcCities.Unlock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Unlock($ID)
  {
    return $this->_sendRpcRequest('RpcCities.Unlock', array($ID), self::$_rpcMethods['Unlock']);
  }

  /**
   * Ruft die RPC-Funktion RpcCities.GetLockData auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcCitieslibRpcLockData
   */
  public function GetLockData($ID)
  {
    return $this->_sendRpcRequest('RpcCities.GetLockData', array($ID), self::$_rpcMethods['GetLockData']);
  }
}
