<?php
/**
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2017 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */


/**
 * RPC-Unit rpc_dataexchangelib.
 *
 * @package GhRpc
 * @subpackage rpc_dataexchangelib
 * @category PHP-RPC-Units
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class rpc_dataexchangelib extends GhRpcLibrary
{
  // RpcDataExchangeImageFormat Konstanten:

  /**
   * deifTiff Konstante (gehört zum Enum: RpcDataExchangeImageFormat).
   */
  const deifTiff = 0;
  /**
   * deifPdf Konstante (gehört zum Enum: RpcDataExchangeImageFormat).
   */
  const deifPdf = 1;

  // RpcDataExchangeState Konstanten:

  /**
   * desNew Konstante (gehört zum Enum: RpcDataExchangeState).
   */
  const desNew = 0;
  /**
   * desFileAvailable Konstante (gehört zum Enum: RpcDataExchangeState).
   */
  const desFileAvailable = 1;
  /**
   * desDone Konstante (gehört zum Enum: RpcDataExchangeState).
   */
  const desDone = 2;
  /**
   * desFailure Konstante (gehört zum Enum: RpcDataExchangeState).
   */
  const desFailure = 3;

  // RpcDataExchangeDoubles Konstanten:

  /**
   * dedInsert Konstante (gehört zum Enum: RpcDataExchangeDoubles).
   */
  const dedInsert = 0;
  /**
   * dedUpdate Konstante (gehört zum Enum: RpcDataExchangeDoubles).
   */
  const dedUpdate = 1;
  /**
   * dedReplace Konstante (gehört zum Enum: RpcDataExchangeDoubles).
   */
  const dedReplace = 2;
  /**
   * dedIgnore Konstante (gehört zum Enum: RpcDataExchangeDoubles).
   */
  const dedIgnore = 3;

  // RpcDataExchangeFormat Konstanten:

  /**
   * defCsv Konstante (gehört zum Enum: RpcDataExchangeFormat).
   */
  const defCsv = 0;
  /**
   * defZip Konstante (gehört zum Enum: RpcDataExchangeFormat).
   */
  const defZip = 1;

  // RpcDataExchangeMode Konstanten:

  /**
   * demImport Konstante (gehört zum Enum: RpcDataExchangeMode).
   */
  const demImport = 0;
  /**
   * demExport Konstante (gehört zum Enum: RpcDataExchangeMode).
   */
  const demExport = 1;

  // RpcLockState Konstanten:

  /**
   * lsUnlocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsUnlocked = 0;
  /**
   * lsModified Konstante (gehört zum Enum: RpcLockState).
   */
  const lsModified = 1;
  /**
   * lsLocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsLocked = 2;

  // RpcDataExchangeKind Konstanten:

  /**
   * dekEmail Konstante (gehört zum Enum: RpcDataExchangeKind).
   */
  const dekEmail = 0;
  /**
   * dekFax Konstante (gehört zum Enum: RpcDataExchangeKind).
   */
  const dekFax = 1;
  /**
   * dekLetter Konstante (gehört zum Enum: RpcDataExchangeKind).
   */
  const dekLetter = 2;
  /**
   * dekShortMessage Konstante (gehört zum Enum: RpcDataExchangeKind).
   */
  const dekShortMessage = 3;
  /**
   * dekCall Konstante (gehört zum Enum: RpcDataExchangeKind).
   */
  const dekCall = 4;
  /**
   * dekAppointment Konstante (gehört zum Enum: RpcDataExchangeKind).
   */
  const dekAppointment = 5;
  /**
   * dekTask Konstante (gehört zum Enum: RpcDataExchangeKind).
   */
  const dekTask = 6;
  /**
   * dekNote Konstante (gehört zum Enum: RpcDataExchangeKind).
   */
  const dekNote = 7;
  /**
   * dekContact Konstante (gehört zum Enum: RpcDataExchangeKind).
   */
  const dekContact = 8;
  /**
   * dekFile Konstante (gehört zum Enum: RpcDataExchangeKind).
   */
  const dekFile = 9;

  /**
   * Hilfskonstante, die ein Set darstellt, in dem alle Enums gesetzt sind.
   * @var int
   */
  const SET_ALL = -1;


  /**
   * Erzeugt eine Instanz des RPC-Dienstes RpcDataExchanges.
   *
   * @param GhRpcClient $client Client Instanz
   *
   * @return GhRpcDataexchangelibRpcDataExchanges
   */
  public static function newRpcDataExchanges(GhRpcClient $client)
  {
    return new GhRpcDataexchangelibRpcDataExchanges($client);
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcField.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcDataexchangelibRpcField
   */
  public static function newRpcField($fillProperties = false)
  {
    $object = new GhRpcDataexchangelibRpcField();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcDataExchangeItem.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcDataexchangelibRpcDataExchangeItem
   */
  public static function newRpcDataExchangeItem($fillProperties = false)
  {
    $object = new GhRpcDataexchangelibRpcDataExchangeItem();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcMapping.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcDataexchangelibRpcMapping
   */
  public static function newRpcMapping($fillProperties = false)
  {
    $object = new GhRpcDataexchangelibRpcMapping();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcLockData.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcDataexchangelibRpcLockData
   */
  public static function newRpcLockData($fillProperties = false)
  {
    $object = new GhRpcDataexchangelibRpcLockData();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcDataExchange.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcDataexchangelibRpcDataExchange
   */
  public static function newRpcDataExchange($fillProperties = false)
  {
    $object = new GhRpcDataexchangelibRpcDataExchange();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }
}


/**
 * RPC-Struct RpcFieldList.
 *
 * @package GhRpc
 * @subpackage rpc_dataexchangelib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcDataexchangelibRpcDataExchange extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * Mode
   * @var int
   */
  public $Mode;

  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * Format
   * @var int
   */
  public $Format;

  /**
   * Kind
   * @var int
   */
  public $Kind;

  /**
   * FilterRef
   * @var int
   */
  public $FilterRef;

  /**
   * IgnoreLines
   * @var int
   */
  public $IgnoreLines;

  /**
   * LineDelimiter
   * @var string
   */
  public $LineDelimiter;

  /**
   * FieldDelimiter
   * @var string
   */
  public $FieldDelimiter;

  /**
   * QuoteChar
   * @var string
   */
  public $QuoteChar;

  /**
   * TrimValues
   * @var boolean
   */
  public $TrimValues;

  /**
   * FieldNames
   * @var boolean
   */
  public $FieldNames;

  /**
   * ImageFormat
   * @var int
   */
  public $ImageFormat;

  /**
   * Doubles
   * @var int
   */
  public $Doubles;

  /**
   * State
   * @var int
   */
  public $State;

  /**
   * CurrentLine
   * @var int
   */
  public $CurrentLine;

  /**
   * Message
   * @var string
   */
  public $Message;

  /**
   * Mappings
   * @var array
   */
  public $Mappings;

  /**
   * LockData
   * @var GhRpcDataexchangelibRpcLockData
   */
  public $LockData;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'Mode' => 'int',
    'Name' => 'string',
    'Format' => 'int',
    'Kind' => 'int',
    'FilterRef' => 'int',
    'IgnoreLines' => 'int',
    'LineDelimiter' => 'string',
    'FieldDelimiter' => 'string',
    'QuoteChar' => 'string',
    'TrimValues' => 'boolean',
    'FieldNames' => 'boolean',
    'ImageFormat' => 'int',
    'Doubles' => 'int',
    'State' => 'int',
    'CurrentLine' => 'int',
    'Message' => 'string',
    'Mappings' => 'array:GhRpcDataexchangelibRpcMapping',
    'LockData' => 'GhRpcDataexchangelibRpcLockData',
    'Created' => 'GhRpcDateTime',
    'Modified' => 'GhRpcDateTime',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcFieldList.
 *
 * @package GhRpc
 * @subpackage rpc_dataexchangelib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcDataexchangelibRpcLockData extends GhRpcStruct
{
  /**
   * LockState
   * @var int
   */
  public $LockState;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * UserName
   * @var string
   */
  public $UserName;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'LockState' => 'int',
    'UserRef' => 'int',
    'UserName' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcFieldList.
 *
 * @package GhRpc
 * @subpackage rpc_dataexchangelib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcDataexchangelibRpcMapping extends GhRpcStruct
{
  /**
   * SrcIndex
   * @var int
   */
  public $SrcIndex;

  /**
   * SrcField
   * @var string
   */
  public $SrcField;

  /**
   * SrcMask
   * @var string
   */
  public $SrcMask;

  /**
   * DstField
   * @var string
   */
  public $DstField;

  /**
   * Default
   * @var string
   */
  public $Default;

  /**
   * ForeignKey
   * @var boolean
   */
  public $ForeignKey;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'SrcIndex' => 'int',
    'SrcField' => 'string',
    'SrcMask' => 'string',
    'DstField' => 'string',
    'Default' => 'string',
    'ForeignKey' => 'boolean',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcFieldList.
 *
 * @package GhRpc
 * @subpackage rpc_dataexchangelib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcDataexchangelibRpcDataExchangeItem extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * Mode
   * @var int
   */
  public $Mode;

  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * Format
   * @var int
   */
  public $Format;

  /**
   * Kind
   * @var int
   */
  public $Kind;

  /**
   * State
   * @var int
   */
  public $State;

  /**
   * Message
   * @var string
   */
  public $Message;

  /**
   * LockData
   * @var GhRpcDataexchangelibRpcLockData
   */
  public $LockData;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'Mode' => 'int',
    'Name' => 'string',
    'Format' => 'int',
    'Kind' => 'int',
    'State' => 'int',
    'Message' => 'string',
    'LockData' => 'GhRpcDataexchangelibRpcLockData',
    'Created' => 'GhRpcDateTime',
    'Modified' => 'GhRpcDateTime',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcFieldList.
 *
 * @package GhRpc
 * @subpackage rpc_dataexchangelib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcDataexchangelibRpcField extends GhRpcStruct
{
  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * Kinds
   * @var int
   */
  public $Kinds;

  /**
   * ForeignKey
   * @var boolean
   */
  public $ForeignKey;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'Name' => 'string',
    'Kinds' => 'int',
    'ForeignKey' => 'boolean',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Dienst RpcDataExchanges
 *
 * @package GhRpc
 * @subpackage rpc_dataexchangelib
 * @category PHP-RPC-Dienste
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcDataexchangelibRpcDataExchanges extends GhRpcService
{
  /**
   * RPC-Methoden mit Parametern und Ergebnistypen.
   * @var array
   */
  protected static $_rpcMethods = array(
    'GetLockData' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcDataexchangelibRpcLockData',
    ),
    'Unlock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Lock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Delete' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Put' => array(
      'params' => array(
        'DataExchange' => 'GhRpcDataexchangelibRpcDataExchange',
      ),
      'return' => '',
    ),
    'New_' => array(
      'params' => array(
        'DataExchange' => 'GhRpcDataexchangelibRpcDataExchange',
        'CreateLocked' => 'boolean',
      ),
      'return' => 'int',
    ),
    'GetFields' => array(
      'params' => array(
      ),
      'return' => 'array:GhRpcDataexchangelibRpcField',
    ),
    'GetList' => array(
      'params' => array(
      ),
      'return' => 'array:GhRpcDataexchangelibRpcDataExchangeItem',
    ),
    'Get' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcDataexchangelibRpcDataExchange',
    ),
  );


  /**
   * Ruft die RPC-Funktion RpcDataExchanges.Get auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcDataexchangelibRpcDataExchange
   */
  public function Get($ID)
  {
    return $this->_sendRpcRequest('RpcDataExchanges.Get', array($ID), self::$_rpcMethods['Get']);
  }

  /**
   * Ruft die RPC-Funktion RpcDataExchanges.GetList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return array
   */
  public function GetList()
  {
    return $this->_sendRpcRequest('RpcDataExchanges.GetList', array(), self::$_rpcMethods['GetList']);
  }

  /**
   * Ruft die RPC-Funktion RpcDataExchanges.GetFields auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return array
   */
  public function GetFields()
  {
    return $this->_sendRpcRequest('RpcDataExchanges.GetFields', array(), self::$_rpcMethods['GetFields']);
  }

  /**
   * Ruft die RPC-Funktion RpcDataExchanges.New auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcDataexchangelibRpcDataExchange $DataExchange
   * @param boolean $CreateLocked
   *
   * @return int
   */
  public function New_(GhRpcDataexchangelibRpcDataExchange $DataExchange, $CreateLocked)
  {
    return $this->_sendRpcRequest('RpcDataExchanges.New', array($DataExchange, $CreateLocked), self::$_rpcMethods['New_']);
  }

  /**
   * Ruft die RPC-Funktion RpcDataExchanges.Put auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcDataexchangelibRpcDataExchange $DataExchange
   */
  public function Put(GhRpcDataexchangelibRpcDataExchange $DataExchange)
  {
    return $this->_sendRpcRequest('RpcDataExchanges.Put', array($DataExchange), self::$_rpcMethods['Put']);
  }

  /**
   * Ruft die RPC-Funktion RpcDataExchanges.Delete auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Delete($ID)
  {
    return $this->_sendRpcRequest('RpcDataExchanges.Delete', array($ID), self::$_rpcMethods['Delete']);
  }

  /**
   * Ruft die RPC-Funktion RpcDataExchanges.Lock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Lock($ID)
  {
    return $this->_sendRpcRequest('RpcDataExchanges.Lock', array($ID), self::$_rpcMethods['Lock']);
  }

  /**
   * Ruft die RPC-Funktion RpcDataExchanges.Unlock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Unlock($ID)
  {
    return $this->_sendRpcRequest('RpcDataExchanges.Unlock', array($ID), self::$_rpcMethods['Unlock']);
  }

  /**
   * Ruft die RPC-Funktion RpcDataExchanges.GetLockData auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcDataexchangelibRpcLockData
   */
  public function GetLockData($ID)
  {
    return $this->_sendRpcRequest('RpcDataExchanges.GetLockData', array($ID), self::$_rpcMethods['GetLockData']);
  }
}
