<?php
/**
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2017 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */


/**
 * RPC-Unit rpc_infolib.
 *
 * @package GhRpc
 * @subpackage rpc_infolib
 * @category PHP-RPC-Units
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class rpc_infolib extends GhRpcLibrary
{
  // RpcItemCountKind Konstanten:

  /**
   * ickTotal Konstante (gehört zum Enum: RpcItemCountKind).
   */
  const ickTotal = 0;
  /**
   * ickRead Konstante (gehört zum Enum: RpcItemCountKind).
   */
  const ickRead = 1;

  // RpcStatusFlag Konstanten:

  /**
   * sfRunning Konstante (gehört zum Enum: RpcStatusFlag).
   */
  const sfRunning = 0;
  /**
   * sfStopped Konstante (gehört zum Enum: RpcStatusFlag).
   */
  const sfStopped = 1;
  /**
   * sfFailure Konstante (gehört zum Enum: RpcStatusFlag).
   */
  const sfFailure = 2;

  // RpcWorkSpace Konstanten:

  /**
   * wsSystem Konstante (gehört zum Enum: RpcWorkSpace).
   */
  const wsSystem = 0;
  /**
   * wsPersonal Konstante (gehört zum Enum: RpcWorkSpace).
   */
  const wsPersonal = 1;

  /**
   * Hilfskonstante, die ein Set darstellt, in dem alle Enums gesetzt sind.
   * @var int
   */
  const SET_ALL = -1;


  /**
   * Erzeugt eine Instanz des RPC-Dienstes RpcInfo.
   *
   * @param GhRpcClient $client Client Instanz
   *
   * @return GhRpcInfolibRpcInfo
   */
  public static function newRpcInfo(GhRpcClient $client)
  {
    return new GhRpcInfolibRpcInfo($client);
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcAddOn.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcInfolibRpcAddOn
   */
  public static function newRpcAddOn($fillProperties = false)
  {
    $object = new GhRpcInfolibRpcAddOn();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcServerSettings.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcInfolibRpcServerSettings
   */
  public static function newRpcServerSettings($fillProperties = false)
  {
    $object = new GhRpcInfolibRpcServerSettings();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcQueueRule.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcInfolibRpcQueueRule
   */
  public static function newRpcQueueRule($fillProperties = false)
  {
    $object = new GhRpcInfolibRpcQueueRule();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcQueueStatus.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcInfolibRpcQueueStatus
   */
  public static function newRpcQueueStatus($fillProperties = false)
  {
    $object = new GhRpcInfolibRpcQueueStatus();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcServerStatus.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcInfolibRpcServerStatus
   */
  public static function newRpcServerStatus($fillProperties = false)
  {
    $object = new GhRpcInfolibRpcServerStatus();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcItemCount.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcInfolibRpcItemCount
   */
  public static function newRpcItemCount($fillProperties = false)
  {
    $object = new GhRpcInfolibRpcItemCount();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcRight.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcInfolibRpcRight
   */
  public static function newRpcRight($fillProperties = false)
  {
    $object = new GhRpcInfolibRpcRight();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcServerInfo.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcInfolibRpcServerInfo
   */
  public static function newRpcServerInfo($fillProperties = false)
  {
    $object = new GhRpcInfolibRpcServerInfo();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }
}


/**
 * RPC-Struct RpcAddOnList.
 *
 * @package GhRpc
 * @subpackage rpc_infolib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcInfolibRpcServerInfo extends GhRpcStruct
{
  /**
   * OnlineSince
   * @var GhRpcDateTime
   */
  public $OnlineSince;

  /**
   * ServerTime
   * @var GhRpcDateTime
   */
  public $ServerTime;

  /**
   * Version
   * @var string
   */
  public $Version;

  /**
   * Connections
   * @var int
   */
  public $Connections;

  /**
   * MaxConnections
   * @var int
   */
  public $MaxConnections;

  /**
   * HttpPort
   * @var int
   */
  public $HttpPort;

  /**
   * RpcpPort
   * @var int
   */
  public $RpcpPort;

  /**
   * KeepAlive
   * @var boolean
   */
  public $KeepAlive;

  /**
   * Compress
   * @var boolean
   */
  public $Compress;

  /**
   * UseRpcps
   * @var boolean
   */
  public $UseRpcps;

  /**
   * UseSSL
   * @var boolean
   */
  public $UseSSL;

  /**
   * MethodCount
   * @var int
   */
  public $MethodCount;

  /**
   * Win32ClientVersion
   * @var string
   */
  public $Win32ClientVersion;

  /**
   * CPU
   * @var string
   */
  public $CPU;

  /**
   * CPUUsage
   * @var int
   */
  public $CPUUsage;

  /**
   * OS
   * @var string
   */
  public $OS;

  /**
   * TotalPhysicalMemory
   * @var GhRpcInt64
   */
  public $TotalPhysicalMemory;

  /**
   * AvailablePhysicalMemory
   * @var GhRpcInt64
   */
  public $AvailablePhysicalMemory;

  /**
   * TotalVirtualMemory
   * @var GhRpcInt64
   */
  public $TotalVirtualMemory;

  /**
   * AvailableVirtualMemory
   * @var GhRpcInt64
   */
  public $AvailableVirtualMemory;

  /**
   * DatabaseSize
   * @var GhRpcInt64
   */
  public $DatabaseSize;

  /**
   * Hostname
   * @var string
   */
  public $Hostname;

  /**
   * IPAddress
   * @var string
   */
  public $IPAddress;

  /**
   * DiskSize
   * @var GhRpcInt64
   */
  public $DiskSize;

  /**
   * DiskFree
   * @var GhRpcInt64
   */
  public $DiskFree;

  /**
   * ServerTimeZone
   * @var string
   */
  public $ServerTimeZone;

  /**
   * BiggestDatabaseTableSize
   * @var GhRpcInt64
   */
  public $BiggestDatabaseTableSize;

  /**
   * Edition
   * @var int
   */
  public $Edition;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'OnlineSince' => 'GhRpcDateTime',
    'ServerTime' => 'GhRpcDateTime',
    'Version' => 'string',
    'Connections' => 'int',
    'MaxConnections' => 'int',
    'HttpPort' => 'int',
    'RpcpPort' => 'int',
    'KeepAlive' => 'boolean',
    'Compress' => 'boolean',
    'UseRpcps' => 'boolean',
    'UseSSL' => 'boolean',
    'MethodCount' => 'int',
    'Win32ClientVersion' => 'string',
    'CPU' => 'string',
    'CPUUsage' => 'int',
    'OS' => 'string',
    'TotalPhysicalMemory' => 'GhRpcInt64',
    'AvailablePhysicalMemory' => 'GhRpcInt64',
    'TotalVirtualMemory' => 'GhRpcInt64',
    'AvailableVirtualMemory' => 'GhRpcInt64',
    'DatabaseSize' => 'GhRpcInt64',
    'Hostname' => 'string',
    'IPAddress' => 'string',
    'DiskSize' => 'GhRpcInt64',
    'DiskFree' => 'GhRpcInt64',
    'ServerTimeZone' => 'string',
    'BiggestDatabaseTableSize' => 'GhRpcInt64',
    'Edition' => 'int',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcAddOnList.
 *
 * @package GhRpc
 * @subpackage rpc_infolib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcInfolibRpcRight extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * ParentRef
   * @var int
   */
  public $ParentRef;

  /**
   * Key
   * @var string
   */
  public $Key;

  /**
   * WorkSpaces
   * @var int
   */
  public $WorkSpaces;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'ParentRef' => 'int',
    'Key' => 'string',
    'WorkSpaces' => 'int',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcAddOnList.
 *
 * @package GhRpc
 * @subpackage rpc_infolib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcInfolibRpcItemCount extends GhRpcStruct
{
  /**
   * TotalCount
   * @var string
   */
  public $TotalCount;

  /**
   * TotalCountUniqueID
   * @var string
   */
  public $TotalCountUniqueID;

  /**
   * TotalCountReset
   * @var boolean
   */
  public $TotalCountReset;

  /**
   * ReadCount
   * @var string
   */
  public $ReadCount;

  /**
   * ReadCountUniqueID
   * @var string
   */
  public $ReadCountUniqueID;

  /**
   * ReadCountReset
   * @var boolean
   */
  public $ReadCountReset;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'TotalCount' => 'binary',
    'TotalCountUniqueID' => 'string',
    'TotalCountReset' => 'boolean',
    'ReadCount' => 'binary',
    'ReadCountUniqueID' => 'string',
    'ReadCountReset' => 'boolean',
    'Modified' => 'GhRpcDateTime',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcAddOnList.
 *
 * @package GhRpc
 * @subpackage rpc_infolib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcInfolibRpcServerStatus extends GhRpcStruct
{
  /**
   * MySqlServer
   * @var int
   */
  public $MySqlServer;

  /**
   * AppServer
   * @var int
   */
  public $AppServer;

  /**
   * QueueServer
   * @var int
   */
  public $QueueServer;

  /**
   * CommServer
   * @var int
   */
  public $CommServer;

  /**
   * GatewayServer
   * @var int
   */
  public $GatewayServer;

  /**
   * AccessServer
   * @var int
   */
  public $AccessServer;

  /**
   * SyncServer
   * @var int
   */
  public $SyncServer;

  /**
   * CommServerLastAction
   * @var string
   */
  public $CommServerLastAction;

  /**
   * QueueServerLastAction
   * @var string
   */
  public $QueueServerLastAction;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'MySqlServer' => 'int',
    'AppServer' => 'int',
    'QueueServer' => 'int',
    'CommServer' => 'int',
    'GatewayServer' => 'int',
    'AccessServer' => 'int',
    'SyncServer' => 'int',
    'CommServerLastAction' => 'string',
    'QueueServerLastAction' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcAddOnList.
 *
 * @package GhRpc
 * @subpackage rpc_infolib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcInfolibRpcQueueStatus extends GhRpcStruct
{
  /**
   * ActionSpamCount
   * @var int
   */
  public $ActionSpamCount;

  /**
   * ActionOcrCount
   * @var int
   */
  public $ActionOcrCount;

  /**
   * ActionHtmlInlineCount
   * @var int
   */
  public $ActionHtmlInlineCount;

  /**
   * ActionWorkflowCount
   * @var int
   */
  public $ActionWorkflowCount;

  /**
   * ActionIndexAddCount
   * @var int
   */
  public $ActionIndexAddCount;

  /**
   * ActionIndexDeleteCount
   * @var int
   */
  public $ActionIndexDeleteCount;

  /**
   * ActionVirusCount
   * @var int
   */
  public $ActionVirusCount;

  /**
   * QueueRules
   * @var array
   */
  public $QueueRules;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ActionSpamCount' => 'int',
    'ActionOcrCount' => 'int',
    'ActionHtmlInlineCount' => 'int',
    'ActionWorkflowCount' => 'int',
    'ActionIndexAddCount' => 'int',
    'ActionIndexDeleteCount' => 'int',
    'ActionVirusCount' => 'int',
    'QueueRules' => 'array:GhRpcInfolibRpcQueueRule',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcAddOnList.
 *
 * @package GhRpc
 * @subpackage rpc_infolib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcInfolibRpcQueueRule extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * ItemCount
   * @var int
   */
  public $ItemCount;

  /**
   * FilterCount
   * @var int
   */
  public $FilterCount;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'Name' => 'string',
    'ItemCount' => 'int',
    'FilterCount' => 'int',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcAddOnList.
 *
 * @package GhRpc
 * @subpackage rpc_infolib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcInfolibRpcServerSettings extends GhRpcStruct
{
  /**
   * PhoneAddressItemCountryPrefix
   * @var string
   */
  public $PhoneAddressItemCountryPrefix;

  /**
   * ElementsPerPage
   * @var int
   */
  public $ElementsPerPage;

  /**
   * ElementsPerList
   * @var int
   */
  public $ElementsPerList;

  /**
   * EventsPerPage
   * @var int
   */
  public $EventsPerPage;

  /**
   * EventsPerDay
   * @var int
   */
  public $EventsPerDay;

  /**
   * MaxSearchResults
   * @var int
   */
  public $MaxSearchResults;

  /**
   * UseItemCount
   * @var boolean
   */
  public $UseItemCount;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'PhoneAddressItemCountryPrefix' => 'string',
    'ElementsPerPage' => 'int',
    'ElementsPerList' => 'int',
    'EventsPerPage' => 'int',
    'EventsPerDay' => 'int',
    'MaxSearchResults' => 'int',
    'UseItemCount' => 'boolean',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcAddOnList.
 *
 * @package GhRpc
 * @subpackage rpc_infolib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcInfolibRpcAddOn extends GhRpcStruct
{
  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * Version
   * @var string
   */
  public $Version;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'Name' => 'string',
    'Version' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Dienst RpcInfo
 *
 * @package GhRpc
 * @subpackage rpc_infolib
 * @category PHP-RPC-Dienste
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcInfolibRpcInfo extends GhRpcService
{
  /**
   * RPC-Methoden mit Parametern und Ergebnistypen.
   * @var array
   */
  protected static $_rpcMethods = array(
    'TrainSpamFilter' => array(
      'params' => array(
      ),
      'return' => '',
    ),
    'GetAddOnList' => array(
      'params' => array(
      ),
      'return' => 'array:GhRpcInfolibRpcAddOn',
    ),
    'GetAddOn' => array(
      'params' => array(
        'Name' => 'string',
      ),
      'return' => 'binary',
    ),
    'UpdateAddOns' => array(
      'params' => array(
      ),
      'return' => '',
    ),
    'GetServerSettings' => array(
      'params' => array(
      ),
      'return' => 'GhRpcInfolibRpcServerSettings',
    ),
    'GetQueueStatus' => array(
      'params' => array(
      ),
      'return' => 'GhRpcInfolibRpcQueueStatus',
    ),
    'GetServerStatus' => array(
      'params' => array(
      ),
      'return' => 'GhRpcInfolibRpcServerStatus',
    ),
    'GetItemCount' => array(
      'params' => array(
        'TotalCountUniqueID' => 'string',
        'ReadCountUniqueID' => 'string',
        'MinModified' => 'GhRpcDateTime',
      ),
      'return' => 'GhRpcInfolibRpcItemCount',
    ),
    'SendAndReceiveNow' => array(
      'params' => array(
      ),
      'return' => '',
    ),
    'ReindexAllItems' => array(
      'params' => array(
      ),
      'return' => '',
    ),
    'InvalidateAllCaches' => array(
      'params' => array(
      ),
      'return' => '',
    ),
    'CountCul' => array(
      'params' => array(
      ),
      'return' => '',
    ),
    'GetRightList' => array(
      'params' => array(
      ),
      'return' => 'array:GhRpcInfolibRpcRight',
    ),
    'GetVariables' => array(
      'params' => array(
      ),
      'return' => 'array:string',
    ),
    'GetServerInfo' => array(
      'params' => array(
        'AdvancedFields' => 'boolean',
      ),
      'return' => 'GhRpcInfolibRpcServerInfo',
    ),
  );


  /**
   * Ruft die RPC-Funktion RpcInfo.GetServerInfo auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param boolean $AdvancedFields
   *
   * @return GhRpcInfolibRpcServerInfo
   */
  public function GetServerInfo($AdvancedFields)
  {
    return $this->_sendRpcRequest('RpcInfo.GetServerInfo', array($AdvancedFields), self::$_rpcMethods['GetServerInfo']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.GetVariables auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return array
   */
  public function GetVariables()
  {
    return $this->_sendRpcRequest('RpcInfo.GetVariables', array(), self::$_rpcMethods['GetVariables']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.GetRightList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return array
   */
  public function GetRightList()
  {
    return $this->_sendRpcRequest('RpcInfo.GetRightList', array(), self::$_rpcMethods['GetRightList']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.CountCul auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   */
  public function CountCul()
  {
    return $this->_sendRpcRequest('RpcInfo.CountCul', array(), self::$_rpcMethods['CountCul']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.InvalidateAllCaches auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   */
  public function InvalidateAllCaches()
  {
    return $this->_sendRpcRequest('RpcInfo.InvalidateAllCaches', array(), self::$_rpcMethods['InvalidateAllCaches']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.ReindexAllItems auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   */
  public function ReindexAllItems()
  {
    return $this->_sendRpcRequest('RpcInfo.ReindexAllItems', array(), self::$_rpcMethods['ReindexAllItems']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.SendAndReceiveNow auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   */
  public function SendAndReceiveNow()
  {
    return $this->_sendRpcRequest('RpcInfo.SendAndReceiveNow', array(), self::$_rpcMethods['SendAndReceiveNow']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.GetItemCount auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $TotalCountUniqueID
   * @param string $ReadCountUniqueID
   * @param GhRpcDateTime $MinModified
   *
   * @return GhRpcInfolibRpcItemCount
   */
  public function GetItemCount($TotalCountUniqueID, $ReadCountUniqueID, GhRpcDateTime $MinModified)
  {
    return $this->_sendRpcRequest('RpcInfo.GetItemCount', array($TotalCountUniqueID, $ReadCountUniqueID, $MinModified), self::$_rpcMethods['GetItemCount']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.GetServerStatus auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return GhRpcInfolibRpcServerStatus
   */
  public function GetServerStatus()
  {
    return $this->_sendRpcRequest('RpcInfo.GetServerStatus', array(), self::$_rpcMethods['GetServerStatus']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.GetQueueStatus auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return GhRpcInfolibRpcQueueStatus
   */
  public function GetQueueStatus()
  {
    return $this->_sendRpcRequest('RpcInfo.GetQueueStatus', array(), self::$_rpcMethods['GetQueueStatus']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.GetServerSettings auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return GhRpcInfolibRpcServerSettings
   */
  public function GetServerSettings()
  {
    return $this->_sendRpcRequest('RpcInfo.GetServerSettings', array(), self::$_rpcMethods['GetServerSettings']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.UpdateAddOns auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   */
  public function UpdateAddOns()
  {
    return $this->_sendRpcRequest('RpcInfo.UpdateAddOns', array(), self::$_rpcMethods['UpdateAddOns']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.GetAddOn auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param string $Name
   *
   * @return string
   */
  public function GetAddOn($Name)
  {
    return $this->_sendRpcRequest('RpcInfo.GetAddOn', array($Name), self::$_rpcMethods['GetAddOn']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.GetAddOnList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return array
   */
  public function GetAddOnList()
  {
    return $this->_sendRpcRequest('RpcInfo.GetAddOnList', array(), self::$_rpcMethods['GetAddOnList']);
  }

  /**
   * Ruft die RPC-Funktion RpcInfo.TrainSpamFilter auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   */
  public function TrainSpamFilter()
  {
    return $this->_sendRpcRequest('RpcInfo.TrainSpamFilter', array(), self::$_rpcMethods['TrainSpamFilter']);
  }
}
