<?php
/**
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2017 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */


/**
 * RPC-Unit rpc_messengerslib.
 *
 * @package GhRpc
 * @subpackage rpc_messengerslib
 * @category PHP-RPC-Units
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class rpc_messengerslib extends GhRpcLibrary
{
  // RpcMessengerMsgKind Konstanten:

  /**
   * mmkIncoming Konstante (gehört zum Enum: RpcMessengerMsgKind).
   */
  const mmkIncoming = 0;
  /**
   * mmkOutgoing Konstante (gehört zum Enum: RpcMessengerMsgKind).
   */
  const mmkOutgoing = 1;
  /**
   * mmkSent Konstante (gehört zum Enum: RpcMessengerMsgKind).
   */
  const mmkSent = 2;
  /**
   * mmkFailure Konstante (gehört zum Enum: RpcMessengerMsgKind).
   */
  const mmkFailure = 3;
  /**
   * mmkRead Konstante (gehört zum Enum: RpcMessengerMsgKind).
   */
  const mmkRead = 4;

  // RpcMessengerState Konstanten:

  /**
   * msInactive Konstante (gehört zum Enum: RpcMessengerState).
   */
  const msInactive = 0;
  /**
   * msActive Konstante (gehört zum Enum: RpcMessengerState).
   */
  const msActive = 1;

  // RpcLockState Konstanten:

  /**
   * lsUnlocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsUnlocked = 0;
  /**
   * lsModified Konstante (gehört zum Enum: RpcLockState).
   */
  const lsModified = 1;
  /**
   * lsLocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsLocked = 2;

  /**
   * Hilfskonstante, die ein Set darstellt, in dem alle Enums gesetzt sind.
   * @var int
   */
  const SET_ALL = -1;


  /**
   * Erzeugt eine Instanz des RPC-Dienstes RpcMessengers.
   *
   * @param GhRpcClient $client Client Instanz
   *
   * @return GhRpcMessengerslibRpcMessengers
   */
  public static function newRpcMessengers(GhRpcClient $client)
  {
    return new GhRpcMessengerslibRpcMessengers($client);
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcMessengerContact.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcMessengerslibRpcMessengerContact
   */
  public static function newRpcMessengerContact($fillProperties = false)
  {
    $object = new GhRpcMessengerslibRpcMessengerContact();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcMessengerMsg.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcMessengerslibRpcMessengerMsg
   */
  public static function newRpcMessengerMsg($fillProperties = false)
  {
    $object = new GhRpcMessengerslibRpcMessengerMsg();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcLockData.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcMessengerslibRpcLockData
   */
  public static function newRpcLockData($fillProperties = false)
  {
    $object = new GhRpcMessengerslibRpcLockData();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcMessenger.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcMessengerslibRpcMessenger
   */
  public static function newRpcMessenger($fillProperties = false)
  {
    $object = new GhRpcMessengerslibRpcMessenger();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }
}


/**
 * RPC-Struct RpcMessengerContactList.
 *
 * @package GhRpc
 * @subpackage rpc_messengerslib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcMessengerslibRpcMessenger extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * State
   * @var int
   */
  public $State;

  /**
   * URL
   * @var string
   */
  public $URL;

  /**
   * Timeout
   * @var int
   */
  public $Timeout;

  /**
   * EndPoint
   * @var string
   */
  public $EndPoint;

  /**
   * Token
   * @var string
   */
  public $Token;

  /**
   * Greeting
   * @var string
   */
  public $Greeting;

  /**
   * LastError
   * @var string
   */
  public $LastError;

  /**
   * BlockList
   * @var array
   */
  public $BlockList;

  /**
   * Picture
   * @var string
   */
  public $Picture;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * LockData
   * @var GhRpcMessengerslibRpcLockData
   */
  public $LockData;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'Name' => 'string',
    'State' => 'int',
    'URL' => 'string',
    'Timeout' => 'int',
    'EndPoint' => 'string',
    'Token' => 'string',
    'Greeting' => 'string',
    'LastError' => 'string',
    'BlockList' => 'array:string',
    'Picture' => 'binary',
    'Created' => 'GhRpcDateTime',
    'Modified' => 'GhRpcDateTime',
    'LockData' => 'GhRpcMessengerslibRpcLockData',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcMessengerContactList.
 *
 * @package GhRpc
 * @subpackage rpc_messengerslib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcMessengerslibRpcLockData extends GhRpcStruct
{
  /**
   * LockState
   * @var int
   */
  public $LockState;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * UserName
   * @var string
   */
  public $UserName;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'LockState' => 'int',
    'UserRef' => 'int',
    'UserName' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcMessengerContactList.
 *
 * @package GhRpc
 * @subpackage rpc_messengerslib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcMessengerslibRpcMessengerMsg extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * MessengerRef
   * @var int
   */
  public $MessengerRef;

  /**
   * Kind
   * @var int
   */
  public $Kind;

  /**
   * ContactRef
   * @var int
   */
  public $ContactRef;

  /**
   * Text
   * @var string
   */
  public $Text;

  /**
   * Preview
   * @var string
   */
  public $Preview;

  /**
   * MimeType
   * @var string
   */
  public $MimeType;

  /**
   * Timestamp
   * @var GhRpcDateTime
   */
  public $Timestamp;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * Username
   * @var string
   */
  public $Username;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'MessengerRef' => 'int',
    'Kind' => 'int',
    'ContactRef' => 'int',
    'Text' => 'string',
    'Preview' => 'binary',
    'MimeType' => 'string',
    'Timestamp' => 'GhRpcDateTime',
    'Modified' => 'GhRpcDateTime',
    'UserRef' => 'int',
    'Username' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcMessengerContactList.
 *
 * @package GhRpc
 * @subpackage rpc_messengerslib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcMessengerslibRpcMessengerContact extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * MessengerRef
   * @var int
   */
  public $MessengerRef;

  /**
   * Identifier
   * @var string
   */
  public $Identifier;

  /**
   * Nickname
   * @var string
   */
  public $Nickname;

  /**
   * LockData
   * @var GhRpcMessengerslibRpcLockData
   */
  public $LockData;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'MessengerRef' => 'int',
    'Identifier' => 'string',
    'Nickname' => 'string',
    'LockData' => 'GhRpcMessengerslibRpcLockData',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Dienst RpcMessengers
 *
 * @package GhRpc
 * @subpackage rpc_messengerslib
 * @category PHP-RPC-Dienste
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcMessengerslibRpcMessengers extends GhRpcService
{
  /**
   * RPC-Methoden mit Parametern und Ergebnistypen.
   * @var array
   */
  protected static $_rpcMethods = array(
    'GetContactLockData' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcMessengerslibRpcLockData',
    ),
    'UnlockContact' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'LockContact' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'GetLockData' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcMessengerslibRpcLockData',
    ),
    'Unlock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Lock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Unlink' => array(
      'params' => array(
        'ID' => 'int',
        'Identifier' => 'string',
      ),
      'return' => '',
    ),
    'GetData' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'binary',
    ),
    'Send' => array(
      'params' => array(
        'ID' => 'int',
        'Identifier' => 'string',
        'Text' => 'string',
        'Preview' => 'binary',
        'BlobData' => 'binary',
        'MimeType' => 'string',
      ),
      'return' => 'int',
    ),
    'Receive' => array(
      'params' => array(
        'ID' => 'int',
        'ContactRef' => 'int',
        'ModifiedSince' => 'GhRpcDateTime',
      ),
      'return' => 'array:GhRpcMessengerslibRpcMessengerMsg',
    ),
    'Contacts' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'array:GhRpcMessengerslibRpcMessengerContact',
    ),
    'Delete' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Put' => array(
      'params' => array(
        'Messenger' => 'GhRpcMessengerslibRpcMessenger',
      ),
      'return' => '',
    ),
    'New_' => array(
      'params' => array(
        'Messenger' => 'GhRpcMessengerslibRpcMessenger',
      ),
      'return' => 'int',
    ),
    'GetList' => array(
      'params' => array(
      ),
      'return' => 'array:GhRpcMessengerslibRpcMessenger',
    ),
    'Get' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcMessengerslibRpcMessenger',
    ),
  );


  /**
   * Ruft die RPC-Funktion RpcMessengers.Get auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcMessengerslibRpcMessenger
   */
  public function Get($ID)
  {
    return $this->_sendRpcRequest('RpcMessengers.Get', array($ID), self::$_rpcMethods['Get']);
  }

  /**
   * Ruft die RPC-Funktion RpcMessengers.GetList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return array
   */
  public function GetList()
  {
    return $this->_sendRpcRequest('RpcMessengers.GetList', array(), self::$_rpcMethods['GetList']);
  }

  /**
   * Ruft die RPC-Funktion RpcMessengers.New auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcMessengerslibRpcMessenger $Messenger
   *
   * @return int
   */
  public function New_(GhRpcMessengerslibRpcMessenger $Messenger)
  {
    return $this->_sendRpcRequest('RpcMessengers.New', array($Messenger), self::$_rpcMethods['New_']);
  }

  /**
   * Ruft die RPC-Funktion RpcMessengers.Put auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcMessengerslibRpcMessenger $Messenger
   */
  public function Put(GhRpcMessengerslibRpcMessenger $Messenger)
  {
    return $this->_sendRpcRequest('RpcMessengers.Put', array($Messenger), self::$_rpcMethods['Put']);
  }

  /**
   * Ruft die RPC-Funktion RpcMessengers.Delete auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Delete($ID)
  {
    return $this->_sendRpcRequest('RpcMessengers.Delete', array($ID), self::$_rpcMethods['Delete']);
  }

  /**
   * Ruft die RPC-Funktion RpcMessengers.Contacts auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return array
   */
  public function Contacts($ID)
  {
    return $this->_sendRpcRequest('RpcMessengers.Contacts', array($ID), self::$_rpcMethods['Contacts']);
  }

  /**
   * Ruft die RPC-Funktion RpcMessengers.Receive auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $ContactRef
   * @param GhRpcDateTime $ModifiedSince
   *
   * @return array
   */
  public function Receive($ID, $ContactRef, GhRpcDateTime $ModifiedSince)
  {
    return $this->_sendRpcRequest('RpcMessengers.Receive', array($ID, $ContactRef, $ModifiedSince), self::$_rpcMethods['Receive']);
  }

  /**
   * Ruft die RPC-Funktion RpcMessengers.Send auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param string $Identifier
   * @param string $Text
   * @param string $Preview
   * @param string $BlobData
   * @param string $MimeType
   *
   * @return int
   */
  public function Send($ID, $Identifier, $Text, $Preview, $BlobData, $MimeType)
  {
    return $this->_sendRpcRequest('RpcMessengers.Send', array($ID, $Identifier, $Text, $Preview, $BlobData, $MimeType), self::$_rpcMethods['Send']);
  }

  /**
   * Ruft die RPC-Funktion RpcMessengers.GetData auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return string
   */
  public function GetData($ID)
  {
    return $this->_sendRpcRequest('RpcMessengers.GetData', array($ID), self::$_rpcMethods['GetData']);
  }

  /**
   * Ruft die RPC-Funktion RpcMessengers.Unlink auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param string $Identifier
   */
  public function Unlink($ID, $Identifier)
  {
    return $this->_sendRpcRequest('RpcMessengers.Unlink', array($ID, $Identifier), self::$_rpcMethods['Unlink']);
  }

  /**
   * Ruft die RPC-Funktion RpcMessengers.Lock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Lock($ID)
  {
    return $this->_sendRpcRequest('RpcMessengers.Lock', array($ID), self::$_rpcMethods['Lock']);
  }

  /**
   * Ruft die RPC-Funktion RpcMessengers.Unlock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Unlock($ID)
  {
    return $this->_sendRpcRequest('RpcMessengers.Unlock', array($ID), self::$_rpcMethods['Unlock']);
  }

  /**
   * Ruft die RPC-Funktion RpcMessengers.GetLockData auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcMessengerslibRpcLockData
   */
  public function GetLockData($ID)
  {
    return $this->_sendRpcRequest('RpcMessengers.GetLockData', array($ID), self::$_rpcMethods['GetLockData']);
  }

  /**
   * Ruft die RPC-Funktion RpcMessengers.LockContact auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function LockContact($ID)
  {
    return $this->_sendRpcRequest('RpcMessengers.LockContact', array($ID), self::$_rpcMethods['LockContact']);
  }

  /**
   * Ruft die RPC-Funktion RpcMessengers.UnlockContact auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function UnlockContact($ID)
  {
    return $this->_sendRpcRequest('RpcMessengers.UnlockContact', array($ID), self::$_rpcMethods['UnlockContact']);
  }

  /**
   * Ruft die RPC-Funktion RpcMessengers.GetContactLockData auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcMessengerslibRpcLockData
   */
  public function GetContactLockData($ID)
  {
    return $this->_sendRpcRequest('RpcMessengers.GetContactLockData', array($ID), self::$_rpcMethods['GetContactLockData']);
  }
}
