<?php
/**
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2017 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */


/**
 * RPC-Unit rpc_profileslib.
 *
 * @package GhRpc
 * @subpackage rpc_profileslib
 * @category PHP-RPC-Units
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class rpc_profileslib extends GhRpcLibrary
{
  // RpcFormatForward Konstanten:

  /**
   * ffText Konstante (gehört zum Enum: RpcFormatForward).
   */
  const ffText = 0;
  /**
   * ffHtml Konstante (gehört zum Enum: RpcFormatForward).
   */
  const ffHtml = 1;
  /**
   * ffAutomatic Konstante (gehört zum Enum: RpcFormatForward).
   */
  const ffAutomatic = 2;

  // RpcFormatAnswer Konstanten:

  /**
   * faText Konstante (gehört zum Enum: RpcFormatAnswer).
   */
  const faText = 0;
  /**
   * faHtml Konstante (gehört zum Enum: RpcFormatAnswer).
   */
  const faHtml = 1;
  /**
   * faAutomatic Konstante (gehört zum Enum: RpcFormatAnswer).
   */
  const faAutomatic = 2;

  // RpcFormatNew Konstanten:

  /**
   * fnText Konstante (gehört zum Enum: RpcFormatNew).
   */
  const fnText = 0;
  /**
   * fnHtml Konstante (gehört zum Enum: RpcFormatNew).
   */
  const fnHtml = 1;

  // RpcLockState Konstanten:

  /**
   * lsUnlocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsUnlocked = 0;
  /**
   * lsModified Konstante (gehört zum Enum: RpcLockState).
   */
  const lsModified = 1;
  /**
   * lsLocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsLocked = 2;

  /**
   * Hilfskonstante, die ein Set darstellt, in dem alle Enums gesetzt sind.
   * @var int
   */
  const SET_ALL = -1;


  /**
   * Erzeugt eine Instanz des RPC-Dienstes RpcProfiles.
   *
   * @param GhRpcClient $client Client Instanz
   *
   * @return GhRpcProfileslibRpcProfiles
   */
  public static function newRpcProfiles(GhRpcClient $client)
  {
    return new GhRpcProfileslibRpcProfiles($client);
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcItemFormat.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcProfileslibRpcItemFormat
   */
  public static function newRpcItemFormat($fillProperties = false)
  {
    $object = new GhRpcProfileslibRpcItemFormat();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcLockData.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcProfileslibRpcLockData
   */
  public static function newRpcLockData($fillProperties = false)
  {
    $object = new GhRpcProfileslibRpcLockData();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcProfile.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcProfileslibRpcProfile
   */
  public static function newRpcProfile($fillProperties = false)
  {
    $object = new GhRpcProfileslibRpcProfile();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }
}


/**
 * RPC-Struct RpcItemFormatList.
 *
 * @package GhRpc
 * @subpackage rpc_profileslib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcProfileslibRpcProfile extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * UserRefs
   * @var array
   */
  public $UserRefs;

  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * SystemRights
   * @var array
   */
  public $SystemRights;

  /**
   * PersonalRights
   * @var array
   */
  public $PersonalRights;

  /**
   * DownFileExts
   * @var array
   */
  public $DownFileExts;

  /**
   * UpFileExts
   * @var array
   */
  public $UpFileExts;

  /**
   * ItemFormats
   * @var array
   */
  public $ItemFormats;

  /**
   * LockData
   * @var GhRpcProfileslibRpcLockData
   */
  public $LockData;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'UserRefs' => 'array:int',
    'Name' => 'string',
    'SystemRights' => 'array:string',
    'PersonalRights' => 'array:string',
    'DownFileExts' => 'array:string',
    'UpFileExts' => 'array:string',
    'ItemFormats' => 'array:GhRpcProfileslibRpcItemFormat',
    'LockData' => 'GhRpcProfileslibRpcLockData',
    'Created' => 'GhRpcDateTime',
    'Modified' => 'GhRpcDateTime',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcItemFormatList.
 *
 * @package GhRpc
 * @subpackage rpc_profileslib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcProfileslibRpcLockData extends GhRpcStruct
{
  /**
   * LockState
   * @var int
   */
  public $LockState;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * UserName
   * @var string
   */
  public $UserName;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'LockState' => 'int',
    'UserRef' => 'int',
    'UserName' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcItemFormatList.
 *
 * @package GhRpc
 * @subpackage rpc_profileslib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcProfileslibRpcItemFormat extends GhRpcStruct
{
  /**
   * New
   * @var int
   */
  public $New;

  /**
   * Answer
   * @var int
   */
  public $Answer;

  /**
   * Forward
   * @var int
   */
  public $Forward;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'New' => 'int',
    'Answer' => 'int',
    'Forward' => 'int',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Dienst RpcProfiles
 *
 * @package GhRpc
 * @subpackage rpc_profileslib
 * @category PHP-RPC-Dienste
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcProfileslibRpcProfiles extends GhRpcService
{
  /**
   * RPC-Methoden mit Parametern und Ergebnistypen.
   * @var array
   */
  protected static $_rpcMethods = array(
    'GetLockData' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcProfileslibRpcLockData',
    ),
    'Unlock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Lock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'AddUser' => array(
      'params' => array(
        'ID' => 'int',
        'UserRef' => 'int',
      ),
      'return' => '',
    ),
    'Delete' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Put' => array(
      'params' => array(
        'Profile' => 'GhRpcProfileslibRpcProfile',
      ),
      'return' => '',
    ),
    'New_' => array(
      'params' => array(
        'Profile' => 'GhRpcProfileslibRpcProfile',
      ),
      'return' => 'int',
    ),
    'GetList' => array(
      'params' => array(
        'AdvancedFields' => 'boolean',
      ),
      'return' => 'array:GhRpcProfileslibRpcProfile',
    ),
    'Get' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcProfileslibRpcProfile',
    ),
  );


  /**
   * Ruft die RPC-Funktion RpcProfiles.Get auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcProfileslibRpcProfile
   */
  public function Get($ID)
  {
    return $this->_sendRpcRequest('RpcProfiles.Get', array($ID), self::$_rpcMethods['Get']);
  }

  /**
   * Ruft die RPC-Funktion RpcProfiles.GetList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param boolean $AdvancedFields
   *
   * @return array
   */
  public function GetList($AdvancedFields)
  {
    return $this->_sendRpcRequest('RpcProfiles.GetList', array($AdvancedFields), self::$_rpcMethods['GetList']);
  }

  /**
   * Ruft die RPC-Funktion RpcProfiles.New auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcProfileslibRpcProfile $Profile
   *
   * @return int
   */
  public function New_(GhRpcProfileslibRpcProfile $Profile)
  {
    return $this->_sendRpcRequest('RpcProfiles.New', array($Profile), self::$_rpcMethods['New_']);
  }

  /**
   * Ruft die RPC-Funktion RpcProfiles.Put auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcProfileslibRpcProfile $Profile
   */
  public function Put(GhRpcProfileslibRpcProfile $Profile)
  {
    return $this->_sendRpcRequest('RpcProfiles.Put', array($Profile), self::$_rpcMethods['Put']);
  }

  /**
   * Ruft die RPC-Funktion RpcProfiles.Delete auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Delete($ID)
  {
    return $this->_sendRpcRequest('RpcProfiles.Delete', array($ID), self::$_rpcMethods['Delete']);
  }

  /**
   * Ruft die RPC-Funktion RpcProfiles.AddUser auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $UserRef
   */
  public function AddUser($ID, $UserRef)
  {
    return $this->_sendRpcRequest('RpcProfiles.AddUser', array($ID, $UserRef), self::$_rpcMethods['AddUser']);
  }

  /**
   * Ruft die RPC-Funktion RpcProfiles.Lock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Lock($ID)
  {
    return $this->_sendRpcRequest('RpcProfiles.Lock', array($ID), self::$_rpcMethods['Lock']);
  }

  /**
   * Ruft die RPC-Funktion RpcProfiles.Unlock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Unlock($ID)
  {
    return $this->_sendRpcRequest('RpcProfiles.Unlock', array($ID), self::$_rpcMethods['Unlock']);
  }

  /**
   * Ruft die RPC-Funktion RpcProfiles.GetLockData auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcProfileslibRpcLockData
   */
  public function GetLockData($ID)
  {
    return $this->_sendRpcRequest('RpcProfiles.GetLockData', array($ID), self::$_rpcMethods['GetLockData']);
  }
}
