<?php
/**
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2017 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */


/**
 * RPC-Unit rpc_quickdialingslib.
 *
 * @package GhRpc
 * @subpackage rpc_quickdialingslib
 * @category PHP-RPC-Units
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class rpc_quickdialingslib extends GhRpcLibrary
{
  // RpcQuickDialingKind Konstanten:

  /**
   * qdkNumber Konstante (gehört zum Enum: RpcQuickDialingKind).
   */
  const qdkNumber = 0;
  /**
   * qdkCommand Konstante (gehört zum Enum: RpcQuickDialingKind).
   */
  const qdkCommand = 1;

  // RpcLockState Konstanten:

  /**
   * lsUnlocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsUnlocked = 0;
  /**
   * lsModified Konstante (gehört zum Enum: RpcLockState).
   */
  const lsModified = 1;
  /**
   * lsLocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsLocked = 2;

  // RpcWorkSpace Konstanten:

  /**
   * wsSystem Konstante (gehört zum Enum: RpcWorkSpace).
   */
  const wsSystem = 0;
  /**
   * wsPersonal Konstante (gehört zum Enum: RpcWorkSpace).
   */
  const wsPersonal = 1;

  /**
   * Hilfskonstante, die ein Set darstellt, in dem alle Enums gesetzt sind.
   * @var int
   */
  const SET_ALL = -1;


  /**
   * Erzeugt eine Instanz des RPC-Dienstes RpcQuickDialings.
   *
   * @param GhRpcClient $client Client Instanz
   *
   * @return GhRpcQuickdialingslibRpcQuickDialings
   */
  public static function newRpcQuickDialings(GhRpcClient $client)
  {
    return new GhRpcQuickdialingslibRpcQuickDialings($client);
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcLockData.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcQuickdialingslibRpcLockData
   */
  public static function newRpcLockData($fillProperties = false)
  {
    $object = new GhRpcQuickdialingslibRpcLockData();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcQuickDialing.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcQuickdialingslibRpcQuickDialing
   */
  public static function newRpcQuickDialing($fillProperties = false)
  {
    $object = new GhRpcQuickdialingslibRpcQuickDialing();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }
}


/**
 * RPC-Struct RpcQuickDialingList.
 *
 * @package GhRpc
 * @subpackage rpc_quickdialingslib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcQuickdialingslibRpcQuickDialing extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * WorkSpace
   * @var int
   */
  public $WorkSpace;

  /**
   * Order
   * @var int
   */
  public $Order;

  /**
   * Kind
   * @var int
   */
  public $Kind;

  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * ButtonText
   * @var string
   */
  public $ButtonText;

  /**
   * Icon
   * @var string
   */
  public $Icon;

  /**
   * Dial
   * @var string
   */
  public $Dial;

  /**
   * LockData
   * @var GhRpcQuickdialingslibRpcLockData
   */
  public $LockData;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'WorkSpace' => 'int',
    'Order' => 'int',
    'Kind' => 'int',
    'Name' => 'string',
    'ButtonText' => 'string',
    'Icon' => 'binary',
    'Dial' => 'string',
    'LockData' => 'GhRpcQuickdialingslibRpcLockData',
    'Created' => 'GhRpcDateTime',
    'Modified' => 'GhRpcDateTime',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcQuickDialingList.
 *
 * @package GhRpc
 * @subpackage rpc_quickdialingslib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcQuickdialingslibRpcLockData extends GhRpcStruct
{
  /**
   * LockState
   * @var int
   */
  public $LockState;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * UserName
   * @var string
   */
  public $UserName;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'LockState' => 'int',
    'UserRef' => 'int',
    'UserName' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Dienst RpcQuickDialings
 *
 * @package GhRpc
 * @subpackage rpc_quickdialingslib
 * @category PHP-RPC-Dienste
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcQuickdialingslibRpcQuickDialings extends GhRpcService
{
  /**
   * RPC-Methoden mit Parametern und Ergebnistypen.
   * @var array
   */
  protected static $_rpcMethods = array(
    'GetLockData' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcQuickdialingslibRpcLockData',
    ),
    'Unlock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Lock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'SetOrder' => array(
      'params' => array(
        'ID' => 'int',
        'Order' => 'int',
      ),
      'return' => '',
    ),
    'Delete' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Put' => array(
      'params' => array(
        'QuickDialing' => 'GhRpcQuickdialingslibRpcQuickDialing',
      ),
      'return' => '',
    ),
    'New_' => array(
      'params' => array(
        'QuickDialing' => 'GhRpcQuickdialingslibRpcQuickDialing',
      ),
      'return' => 'int',
    ),
    'GetList' => array(
      'params' => array(
      ),
      'return' => 'array:GhRpcQuickdialingslibRpcQuickDialing',
    ),
    'Get' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcQuickdialingslibRpcQuickDialing',
    ),
  );


  /**
   * Ruft die RPC-Funktion RpcQuickDialings.Get auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcQuickdialingslibRpcQuickDialing
   */
  public function Get($ID)
  {
    return $this->_sendRpcRequest('RpcQuickDialings.Get', array($ID), self::$_rpcMethods['Get']);
  }

  /**
   * Ruft die RPC-Funktion RpcQuickDialings.GetList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return array
   */
  public function GetList()
  {
    return $this->_sendRpcRequest('RpcQuickDialings.GetList', array(), self::$_rpcMethods['GetList']);
  }

  /**
   * Ruft die RPC-Funktion RpcQuickDialings.New auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcQuickdialingslibRpcQuickDialing $QuickDialing
   *
   * @return int
   */
  public function New_(GhRpcQuickdialingslibRpcQuickDialing $QuickDialing)
  {
    return $this->_sendRpcRequest('RpcQuickDialings.New', array($QuickDialing), self::$_rpcMethods['New_']);
  }

  /**
   * Ruft die RPC-Funktion RpcQuickDialings.Put auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcQuickdialingslibRpcQuickDialing $QuickDialing
   */
  public function Put(GhRpcQuickdialingslibRpcQuickDialing $QuickDialing)
  {
    return $this->_sendRpcRequest('RpcQuickDialings.Put', array($QuickDialing), self::$_rpcMethods['Put']);
  }

  /**
   * Ruft die RPC-Funktion RpcQuickDialings.Delete auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Delete($ID)
  {
    return $this->_sendRpcRequest('RpcQuickDialings.Delete', array($ID), self::$_rpcMethods['Delete']);
  }

  /**
   * Ruft die RPC-Funktion RpcQuickDialings.SetOrder auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $Order
   */
  public function SetOrder($ID, $Order)
  {
    return $this->_sendRpcRequest('RpcQuickDialings.SetOrder', array($ID, $Order), self::$_rpcMethods['SetOrder']);
  }

  /**
   * Ruft die RPC-Funktion RpcQuickDialings.Lock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Lock($ID)
  {
    return $this->_sendRpcRequest('RpcQuickDialings.Lock', array($ID), self::$_rpcMethods['Lock']);
  }

  /**
   * Ruft die RPC-Funktion RpcQuickDialings.Unlock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Unlock($ID)
  {
    return $this->_sendRpcRequest('RpcQuickDialings.Unlock', array($ID), self::$_rpcMethods['Unlock']);
  }

  /**
   * Ruft die RPC-Funktion RpcQuickDialings.GetLockData auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcQuickdialingslibRpcLockData
   */
  public function GetLockData($ID)
  {
    return $this->_sendRpcRequest('RpcQuickDialings.GetLockData', array($ID), self::$_rpcMethods['GetLockData']);
  }
}
