<?php
/**
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2017 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */


/**
 * RPC-Unit rpc_smtpaccountslib.
 *
 * @package GhRpc
 * @subpackage rpc_smtpaccountslib
 * @category PHP-RPC-Units
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class rpc_smtpaccountslib extends GhRpcLibrary
{
  // RpcSmtpSslKind Konstanten:

  /**
   * sskAuto Konstante (gehört zum Enum: RpcSmtpSslKind).
   */
  const sskAuto = 0;
  /**
   * sskSslv2 Konstante (gehört zum Enum: RpcSmtpSslKind).
   */
  const sskSslv2 = 1;
  /**
   * sskSslv3 Konstante (gehört zum Enum: RpcSmtpSslKind).
   */
  const sskSslv3 = 2;
  /**
   * sskTlsv1 Konstante (gehört zum Enum: RpcSmtpSslKind).
   */
  const sskTlsv1 = 3;
  /**
   * sskTlsv11 Konstante (gehört zum Enum: RpcSmtpSslKind).
   */
  const sskTlsv11 = 4;
  /**
   * sskTlsv12 Konstante (gehört zum Enum: RpcSmtpSslKind).
   */
  const sskTlsv12 = 5;

  // RpcSmtpFlag Konstanten:

  /**
   * sfOverwriteFrom Konstante (gehört zum Enum: RpcSmtpFlag).
   */
  const sfOverwriteFrom = 0;
  /**
   * sfOverwriteTo Konstante (gehört zum Enum: RpcSmtpFlag).
   */
  const sfOverwriteTo = 1;

  // RpcLockState Konstanten:

  /**
   * lsUnlocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsUnlocked = 0;
  /**
   * lsModified Konstante (gehört zum Enum: RpcLockState).
   */
  const lsModified = 1;
  /**
   * lsLocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsLocked = 2;

  // RpcSmtpEncrypt Konstanten:

  /**
   * seNo Konstante (gehört zum Enum: RpcSmtpEncrypt).
   */
  const seNo = 0;
  /**
   * seSSL Konstante (gehört zum Enum: RpcSmtpEncrypt).
   */
  const seSSL = 1;
  /**
   * seSTARTTLS Konstante (gehört zum Enum: RpcSmtpEncrypt).
   */
  const seSTARTTLS = 2;

  // RpcSmtpAuthenticate Konstanten:

  /**
   * saYes Konstante (gehört zum Enum: RpcSmtpAuthenticate).
   */
  const saYes = 0;
  /**
   * saNo Konstante (gehört zum Enum: RpcSmtpAuthenticate).
   */
  const saNo = 1;

  // RpcSmtpKind Konstanten:

  /**
   * skEmail Konstante (gehört zum Enum: RpcSmtpKind).
   */
  const skEmail = 0;
  /**
   * skFax Konstante (gehört zum Enum: RpcSmtpKind).
   */
  const skFax = 1;
  /**
   * skLetter Konstante (gehört zum Enum: RpcSmtpKind).
   */
  const skLetter = 2;
  /**
   * skShortMessage Konstante (gehört zum Enum: RpcSmtpKind).
   */
  const skShortMessage = 3;

  // RpcSmtpState Konstanten:

  /**
   * ssInactive Konstante (gehört zum Enum: RpcSmtpState).
   */
  const ssInactive = 0;
  /**
   * ssActive Konstante (gehört zum Enum: RpcSmtpState).
   */
  const ssActive = 1;

  /**
   * Hilfskonstante, die ein Set darstellt, in dem alle Enums gesetzt sind.
   * @var int
   */
  const SET_ALL = -1;


  /**
   * Erzeugt eine Instanz des RPC-Dienstes RpcSmtpAccounts.
   *
   * @param GhRpcClient $client Client Instanz
   *
   * @return GhRpcSmtpaccountslibRpcSmtpAccounts
   */
  public static function newRpcSmtpAccounts(GhRpcClient $client)
  {
    return new GhRpcSmtpaccountslibRpcSmtpAccounts($client);
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcLockData.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcSmtpaccountslibRpcLockData
   */
  public static function newRpcLockData($fillProperties = false)
  {
    $object = new GhRpcSmtpaccountslibRpcLockData();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcSmtpAccountItem.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcSmtpaccountslibRpcSmtpAccountItem
   */
  public static function newRpcSmtpAccountItem($fillProperties = false)
  {
    $object = new GhRpcSmtpaccountslibRpcSmtpAccountItem();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcSmtpAccount.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcSmtpaccountslibRpcSmtpAccount
   */
  public static function newRpcSmtpAccount($fillProperties = false)
  {
    $object = new GhRpcSmtpaccountslibRpcSmtpAccount();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }
}


/**
 * RPC-Struct RpcSmtpAccountList.
 *
 * @package GhRpc
 * @subpackage rpc_smtpaccountslib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcSmtpaccountslibRpcSmtpAccount extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * State
   * @var int
   */
  public $State;

  /**
   * Host
   * @var string
   */
  public $Host;

  /**
   * Port
   * @var int
   */
  public $Port;

  /**
   * Timeout
   * @var int
   */
  public $Timeout;

  /**
   * MaxSize
   * @var int
   */
  public $MaxSize;

  /**
   * Authenticate
   * @var int
   */
  public $Authenticate;

  /**
   * Encrypt
   * @var int
   */
  public $Encrypt;

  /**
   * SslKind
   * @var int
   */
  public $SslKind;

  /**
   * Username
   * @var string
   */
  public $Username;

  /**
   * Password
   * @var string
   */
  public $Password;

  /**
   * Kind
   * @var int
   */
  public $Kind;

  /**
   * Filter
   * @var string
   */
  public $Filter;

  /**
   * Flags
   * @var int
   */
  public $Flags;

  /**
   * FromOverwrite
   * @var string
   */
  public $FromOverwrite;

  /**
   * ToOverwrite
   * @var string
   */
  public $ToOverwrite;

  /**
   * ErrorCount
   * @var int
   */
  public $ErrorCount;

  /**
   * Message
   * @var string
   */
  public $Message;

  /**
   * LockData
   * @var GhRpcSmtpaccountslibRpcLockData
   */
  public $LockData;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'Name' => 'string',
    'State' => 'int',
    'Host' => 'string',
    'Port' => 'int',
    'Timeout' => 'int',
    'MaxSize' => 'int',
    'Authenticate' => 'int',
    'Encrypt' => 'int',
    'SslKind' => 'int',
    'Username' => 'string',
    'Password' => 'string',
    'Kind' => 'int',
    'Filter' => 'string',
    'Flags' => 'int',
    'FromOverwrite' => 'string',
    'ToOverwrite' => 'string',
    'ErrorCount' => 'int',
    'Message' => 'string',
    'LockData' => 'GhRpcSmtpaccountslibRpcLockData',
    'Created' => 'GhRpcDateTime',
    'Modified' => 'GhRpcDateTime',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcSmtpAccountList.
 *
 * @package GhRpc
 * @subpackage rpc_smtpaccountslib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcSmtpaccountslibRpcSmtpAccountItem extends GhRpcStruct
{
  /**
   * Host
   * @var string
   */
  public $Host;

  /**
   * Port
   * @var int
   */
  public $Port;

  /**
   * Timeout
   * @var int
   */
  public $Timeout;

  /**
   * Authenticate
   * @var int
   */
  public $Authenticate;

  /**
   * Encrypt
   * @var int
   */
  public $Encrypt;

  /**
   * SslKind
   * @var int
   */
  public $SslKind;

  /**
   * Username
   * @var string
   */
  public $Username;

  /**
   * Password
   * @var string
   */
  public $Password;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'Host' => 'string',
    'Port' => 'int',
    'Timeout' => 'int',
    'Authenticate' => 'int',
    'Encrypt' => 'int',
    'SslKind' => 'int',
    'Username' => 'string',
    'Password' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcSmtpAccountList.
 *
 * @package GhRpc
 * @subpackage rpc_smtpaccountslib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcSmtpaccountslibRpcLockData extends GhRpcStruct
{
  /**
   * LockState
   * @var int
   */
  public $LockState;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * UserName
   * @var string
   */
  public $UserName;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'LockState' => 'int',
    'UserRef' => 'int',
    'UserName' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Dienst RpcSmtpAccounts
 *
 * @package GhRpc
 * @subpackage rpc_smtpaccountslib
 * @category PHP-RPC-Dienste
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcSmtpaccountslibRpcSmtpAccounts extends GhRpcService
{
  /**
   * RPC-Methoden mit Parametern und Ergebnistypen.
   * @var array
   */
  protected static $_rpcMethods = array(
    'GetLockData' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcSmtpaccountslibRpcLockData',
    ),
    'Unlock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Lock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'CheckConnection' => array(
      'params' => array(
        'SmtpAccountItem' => 'GhRpcSmtpaccountslibRpcSmtpAccountItem',
      ),
      'return' => '',
    ),
    'Delete' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Put' => array(
      'params' => array(
        'SmtpAccount' => 'GhRpcSmtpaccountslibRpcSmtpAccount',
      ),
      'return' => '',
    ),
    'New_' => array(
      'params' => array(
        'SmtpAccount' => 'GhRpcSmtpaccountslibRpcSmtpAccount',
      ),
      'return' => 'int',
    ),
    'GetList' => array(
      'params' => array(
      ),
      'return' => 'array:GhRpcSmtpaccountslibRpcSmtpAccount',
    ),
    'Get' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcSmtpaccountslibRpcSmtpAccount',
    ),
  );


  /**
   * Ruft die RPC-Funktion RpcSmtpAccounts.Get auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcSmtpaccountslibRpcSmtpAccount
   */
  public function Get($ID)
  {
    return $this->_sendRpcRequest('RpcSmtpAccounts.Get', array($ID), self::$_rpcMethods['Get']);
  }

  /**
   * Ruft die RPC-Funktion RpcSmtpAccounts.GetList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return array
   */
  public function GetList()
  {
    return $this->_sendRpcRequest('RpcSmtpAccounts.GetList', array(), self::$_rpcMethods['GetList']);
  }

  /**
   * Ruft die RPC-Funktion RpcSmtpAccounts.New auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcSmtpaccountslibRpcSmtpAccount $SmtpAccount
   *
   * @return int
   */
  public function New_(GhRpcSmtpaccountslibRpcSmtpAccount $SmtpAccount)
  {
    return $this->_sendRpcRequest('RpcSmtpAccounts.New', array($SmtpAccount), self::$_rpcMethods['New_']);
  }

  /**
   * Ruft die RPC-Funktion RpcSmtpAccounts.Put auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcSmtpaccountslibRpcSmtpAccount $SmtpAccount
   */
  public function Put(GhRpcSmtpaccountslibRpcSmtpAccount $SmtpAccount)
  {
    return $this->_sendRpcRequest('RpcSmtpAccounts.Put', array($SmtpAccount), self::$_rpcMethods['Put']);
  }

  /**
   * Ruft die RPC-Funktion RpcSmtpAccounts.Delete auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Delete($ID)
  {
    return $this->_sendRpcRequest('RpcSmtpAccounts.Delete', array($ID), self::$_rpcMethods['Delete']);
  }

  /**
   * Ruft die RPC-Funktion RpcSmtpAccounts.CheckConnection auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcSmtpaccountslibRpcSmtpAccountItem $SmtpAccountItem
   */
  public function CheckConnection(GhRpcSmtpaccountslibRpcSmtpAccountItem $SmtpAccountItem)
  {
    return $this->_sendRpcRequest('RpcSmtpAccounts.CheckConnection', array($SmtpAccountItem), self::$_rpcMethods['CheckConnection']);
  }

  /**
   * Ruft die RPC-Funktion RpcSmtpAccounts.Lock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Lock($ID)
  {
    return $this->_sendRpcRequest('RpcSmtpAccounts.Lock', array($ID), self::$_rpcMethods['Lock']);
  }

  /**
   * Ruft die RPC-Funktion RpcSmtpAccounts.Unlock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Unlock($ID)
  {
    return $this->_sendRpcRequest('RpcSmtpAccounts.Unlock', array($ID), self::$_rpcMethods['Unlock']);
  }

  /**
   * Ruft die RPC-Funktion RpcSmtpAccounts.GetLockData auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcSmtpaccountslibRpcLockData
   */
  public function GetLockData($ID)
  {
    return $this->_sendRpcRequest('RpcSmtpAccounts.GetLockData', array($ID), self::$_rpcMethods['GetLockData']);
  }
}
