<?php
/**
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2017 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */


/**
 * RPC-Unit rpc_stopwordslib.
 *
 * @package GhRpc
 * @subpackage rpc_stopwordslib
 * @category PHP-RPC-Units
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class rpc_stopwordslib extends GhRpcLibrary
{
  // RpcLockState Konstanten:

  /**
   * lsUnlocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsUnlocked = 0;
  /**
   * lsModified Konstante (gehört zum Enum: RpcLockState).
   */
  const lsModified = 1;
  /**
   * lsLocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsLocked = 2;

  /**
   * Hilfskonstante, die ein Set darstellt, in dem alle Enums gesetzt sind.
   * @var int
   */
  const SET_ALL = -1;


  /**
   * Erzeugt eine Instanz des RPC-Dienstes RpcStopwords.
   *
   * @param GhRpcClient $client Client Instanz
   *
   * @return GhRpcStopwordslibRpcStopwords
   */
  public static function newRpcStopwords(GhRpcClient $client)
  {
    return new GhRpcStopwordslibRpcStopwords($client);
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcLockData.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcStopwordslibRpcLockData
   */
  public static function newRpcLockData($fillProperties = false)
  {
    $object = new GhRpcStopwordslibRpcLockData();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcStopword.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcStopwordslibRpcStopword
   */
  public static function newRpcStopword($fillProperties = false)
  {
    $object = new GhRpcStopwordslibRpcStopword();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }
}


/**
 * RPC-Struct RpcStopwordList.
 *
 * @package GhRpc
 * @subpackage rpc_stopwordslib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcStopwordslibRpcStopword extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * Text
   * @var string
   */
  public $Text;

  /**
   * LockData
   * @var GhRpcStopwordslibRpcLockData
   */
  public $LockData;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'Text' => 'string',
    'LockData' => 'GhRpcStopwordslibRpcLockData',
    'Created' => 'GhRpcDateTime',
    'Modified' => 'GhRpcDateTime',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcStopwordList.
 *
 * @package GhRpc
 * @subpackage rpc_stopwordslib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcStopwordslibRpcLockData extends GhRpcStruct
{
  /**
   * LockState
   * @var int
   */
  public $LockState;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * UserName
   * @var string
   */
  public $UserName;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'LockState' => 'int',
    'UserRef' => 'int',
    'UserName' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Dienst RpcStopwords
 *
 * @package GhRpc
 * @subpackage rpc_stopwordslib
 * @category PHP-RPC-Dienste
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcStopwordslibRpcStopwords extends GhRpcService
{
  /**
   * RPC-Methoden mit Parametern und Ergebnistypen.
   * @var array
   */
  protected static $_rpcMethods = array(
    'GetLockData' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcStopwordslibRpcLockData',
    ),
    'Unlock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Lock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Delete' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Put' => array(
      'params' => array(
        'Stopword' => 'GhRpcStopwordslibRpcStopword',
      ),
      'return' => '',
    ),
    'New_' => array(
      'params' => array(
        'Stopword' => 'GhRpcStopwordslibRpcStopword',
      ),
      'return' => 'int',
    ),
    'GetList' => array(
      'params' => array(
      ),
      'return' => 'array:GhRpcStopwordslibRpcStopword',
    ),
    'Get' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcStopwordslibRpcStopword',
    ),
  );


  /**
   * Ruft die RPC-Funktion RpcStopwords.Get auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcStopwordslibRpcStopword
   */
  public function Get($ID)
  {
    return $this->_sendRpcRequest('RpcStopwords.Get', array($ID), self::$_rpcMethods['Get']);
  }

  /**
   * Ruft die RPC-Funktion RpcStopwords.GetList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return array
   */
  public function GetList()
  {
    return $this->_sendRpcRequest('RpcStopwords.GetList', array(), self::$_rpcMethods['GetList']);
  }

  /**
   * Ruft die RPC-Funktion RpcStopwords.New auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcStopwordslibRpcStopword $Stopword
   *
   * @return int
   */
  public function New_(GhRpcStopwordslibRpcStopword $Stopword)
  {
    return $this->_sendRpcRequest('RpcStopwords.New', array($Stopword), self::$_rpcMethods['New_']);
  }

  /**
   * Ruft die RPC-Funktion RpcStopwords.Put auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcStopwordslibRpcStopword $Stopword
   */
  public function Put(GhRpcStopwordslibRpcStopword $Stopword)
  {
    return $this->_sendRpcRequest('RpcStopwords.Put', array($Stopword), self::$_rpcMethods['Put']);
  }

  /**
   * Ruft die RPC-Funktion RpcStopwords.Delete auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Delete($ID)
  {
    return $this->_sendRpcRequest('RpcStopwords.Delete', array($ID), self::$_rpcMethods['Delete']);
  }

  /**
   * Ruft die RPC-Funktion RpcStopwords.Lock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Lock($ID)
  {
    return $this->_sendRpcRequest('RpcStopwords.Lock', array($ID), self::$_rpcMethods['Lock']);
  }

  /**
   * Ruft die RPC-Funktion RpcStopwords.Unlock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Unlock($ID)
  {
    return $this->_sendRpcRequest('RpcStopwords.Unlock', array($ID), self::$_rpcMethods['Unlock']);
  }

  /**
   * Ruft die RPC-Funktion RpcStopwords.GetLockData auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcStopwordslibRpcLockData
   */
  public function GetLockData($ID)
  {
    return $this->_sendRpcRequest('RpcStopwords.GetLockData', array($ID), self::$_rpcMethods['GetLockData']);
  }
}
