<?php
/**
 * GREYHOUND PHP API
 *
 * Copyright (c) 2011-2017 digital guru GmbH & Co. KG
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of the GREYHOUND PHP API and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Software, and to permit persons to
 * whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */


/**
 * RPC-Unit rpc_userfieldslib.
 *
 * @package GhRpc
 * @subpackage rpc_userfieldslib
 * @category PHP-RPC-Units
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class rpc_userfieldslib extends GhRpcLibrary
{
  // RpcUserFieldKind Konstanten:

  /**
   * ufkEmail Konstante (gehört zum Enum: RpcUserFieldKind).
   */
  const ufkEmail = 0;
  /**
   * ufkFax Konstante (gehört zum Enum: RpcUserFieldKind).
   */
  const ufkFax = 1;
  /**
   * ufkLetter Konstante (gehört zum Enum: RpcUserFieldKind).
   */
  const ufkLetter = 2;
  /**
   * ufkShortMessage Konstante (gehört zum Enum: RpcUserFieldKind).
   */
  const ufkShortMessage = 3;
  /**
   * ufkCall Konstante (gehört zum Enum: RpcUserFieldKind).
   */
  const ufkCall = 4;
  /**
   * ufkAppointment Konstante (gehört zum Enum: RpcUserFieldKind).
   */
  const ufkAppointment = 5;
  /**
   * ufkTask Konstante (gehört zum Enum: RpcUserFieldKind).
   */
  const ufkTask = 6;
  /**
   * ufkNote Konstante (gehört zum Enum: RpcUserFieldKind).
   */
  const ufkNote = 7;
  /**
   * ufkContact Konstante (gehört zum Enum: RpcUserFieldKind).
   */
  const ufkContact = 8;
  /**
   * ufkFile Konstante (gehört zum Enum: RpcUserFieldKind).
   */
  const ufkFile = 9;
  /**
   * ufkUser Konstante (gehört zum Enum: RpcUserFieldKind).
   */
  const ufkUser = 10;

  // RpcUserFieldDataType Konstanten:

  /**
   * ufdtString Konstante (gehört zum Enum: RpcUserFieldDataType).
   */
  const ufdtString = 0;
  /**
   * ufdtInteger Konstante (gehört zum Enum: RpcUserFieldDataType).
   */
  const ufdtInteger = 1;
  /**
   * ufdtInt64 Konstante (gehört zum Enum: RpcUserFieldDataType).
   */
  const ufdtInt64 = 2;
  /**
   * ufdtBoolean Konstante (gehört zum Enum: RpcUserFieldDataType).
   */
  const ufdtBoolean = 3;
  /**
   * ufdtDateTime Konstante (gehört zum Enum: RpcUserFieldDataType).
   */
  const ufdtDateTime = 4;
  /**
   * ufdtFloat Konstante (gehört zum Enum: RpcUserFieldDataType).
   */
  const ufdtFloat = 5;
  /**
   * ufdtBlob Konstante (gehört zum Enum: RpcUserFieldDataType).
   */
  const ufdtBlob = 6;

  // RpcLockState Konstanten:

  /**
   * lsUnlocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsUnlocked = 0;
  /**
   * lsModified Konstante (gehört zum Enum: RpcLockState).
   */
  const lsModified = 1;
  /**
   * lsLocked Konstante (gehört zum Enum: RpcLockState).
   */
  const lsLocked = 2;

  /**
   * Hilfskonstante, die ein Set darstellt, in dem alle Enums gesetzt sind.
   * @var int
   */
  const SET_ALL = -1;


  /**
   * Erzeugt eine Instanz des RPC-Dienstes RpcUserFields.
   *
   * @param GhRpcClient $client Client Instanz
   *
   * @return GhRpcUserfieldslibRpcUserFields
   */
  public static function newRpcUserFields(GhRpcClient $client)
  {
    return new GhRpcUserfieldslibRpcUserFields($client);
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcLockData.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcUserfieldslibRpcLockData
   */
  public static function newRpcLockData($fillProperties = false)
  {
    $object = new GhRpcUserfieldslibRpcLockData();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }

  /**
   * Erzeugt eine Instanz des RPC-Structs RpcUserField.
   *
   * @param boolean $fillProperties true: Objekt-Eigenschaften mit leeren Objekten / Arrays vorbefüllen
   * @return GhRpcUserfieldslibRpcUserField
   */
  public static function newRpcUserField($fillProperties = false)
  {
    $object = new GhRpcUserfieldslibRpcUserField();

    if($fillProperties)
        $object = self::_fillProperties($object);

    return $object;
  }
}


/**
 * RPC-Struct RpcUserFieldList.
 *
 * @package GhRpc
 * @subpackage rpc_userfieldslib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcUserfieldslibRpcUserField extends GhRpcStruct
{
  /**
   * ID
   * @var int
   */
  public $ID;

  /**
   * Name
   * @var string
   */
  public $Name;

  /**
   * Description
   * @var string
   */
  public $Description;

  /**
   * DataType
   * @var int
   */
  public $DataType;

  /**
   * Kinds
   * @var int
   */
  public $Kinds;

  /**
   * Validation
   * @var string
   */
  public $Validation;

  /**
   * Regex
   * @var string
   */
  public $Regex;

  /**
   * Match
   * @var string
   */
  public $Match;

  /**
   * RemoveChars
   * @var string
   */
  public $RemoveChars;

  /**
   * Weight
   * @var int
   */
  public $Weight;

  /**
   * Order
   * @var int
   */
  public $Order;

  /**
   * LockData
   * @var GhRpcUserfieldslibRpcLockData
   */
  public $LockData;

  /**
   * Created
   * @var GhRpcDateTime
   */
  public $Created;

  /**
   * Modified
   * @var GhRpcDateTime
   */
  public $Modified;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'ID' => 'int',
    'Name' => 'string',
    'Description' => 'string',
    'DataType' => 'int',
    'Kinds' => 'int',
    'Validation' => 'string',
    'Regex' => 'string',
    'Match' => 'string',
    'RemoveChars' => 'string',
    'Weight' => 'int',
    'Order' => 'int',
    'LockData' => 'GhRpcUserfieldslibRpcLockData',
    'Created' => 'GhRpcDateTime',
    'Modified' => 'GhRpcDateTime',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Struct RpcUserFieldList.
 *
 * @package GhRpc
 * @subpackage rpc_userfieldslib
 * @category PHP-RPC-Datenklassen
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcUserfieldslibRpcLockData extends GhRpcStruct
{
  /**
   * LockState
   * @var int
   */
  public $LockState;

  /**
   * UserRef
   * @var int
   */
  public $UserRef;

  /**
   * UserName
   * @var string
   */
  public $UserName;

  /**
   * Eigenschaften und Typen des RPC-Structs.
   * @var array
   */
  protected static $_rpcProperties = array(
    'LockState' => 'int',
    'UserRef' => 'int',
    'UserName' => 'string',
  );


  /**
   * Liefert die Eigenschaften dieses RPC-Structs.
   *
   * @return array
   */
  public function getRpcProperties()
  {
    return self::$_rpcProperties;
  }

  /**
   * Liefert den Typ einer Eigenschaft dieses RPC-Structs.
   *
   * @param string $property Name der Eigenschaft
   * @return string
   */
  public function getRpcPropertyType($property)
  {
    return isset(self::$_rpcProperties[$property]) ? self::$_rpcProperties[$property] : null;
  }
}


/**
 * RPC-Dienst RpcUserFields
 *
 * @package GhRpc
 * @subpackage rpc_userfieldslib
 * @category PHP-RPC-Dienste
 *
 * @author digital guru GmbH &amp; Co. KG <develop@greyhound-software.com>
 * @copyright 2011-2017 digital guru GmbH &amp; Co. KG
 * @link greyhound-software.com
 */
class GhRpcUserfieldslibRpcUserFields extends GhRpcService
{
  /**
   * RPC-Methoden mit Parametern und Ergebnistypen.
   * @var array
   */
  protected static $_rpcMethods = array(
    'GetLockData' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcUserfieldslibRpcLockData',
    ),
    'Unlock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Lock' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'SetOrder' => array(
      'params' => array(
        'ID' => 'int',
        'Order' => 'int',
      ),
      'return' => '',
    ),
    'Delete' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => '',
    ),
    'Put' => array(
      'params' => array(
        'UserField' => 'GhRpcUserfieldslibRpcUserField',
      ),
      'return' => '',
    ),
    'New_' => array(
      'params' => array(
        'UserField' => 'GhRpcUserfieldslibRpcUserField',
      ),
      'return' => 'int',
    ),
    'GetList' => array(
      'params' => array(
      ),
      'return' => 'array:GhRpcUserfieldslibRpcUserField',
    ),
    'Get' => array(
      'params' => array(
        'ID' => 'int',
      ),
      'return' => 'GhRpcUserfieldslibRpcUserField',
    ),
  );


  /**
   * Ruft die RPC-Funktion RpcUserFields.Get auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcUserfieldslibRpcUserField
   */
  public function Get($ID)
  {
    return $this->_sendRpcRequest('RpcUserFields.Get', array($ID), self::$_rpcMethods['Get']);
  }

  /**
   * Ruft die RPC-Funktion RpcUserFields.GetList auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @return array
   */
  public function GetList()
  {
    return $this->_sendRpcRequest('RpcUserFields.GetList', array(), self::$_rpcMethods['GetList']);
  }

  /**
   * Ruft die RPC-Funktion RpcUserFields.New auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcUserfieldslibRpcUserField $UserField
   *
   * @return int
   */
  public function New_(GhRpcUserfieldslibRpcUserField $UserField)
  {
    return $this->_sendRpcRequest('RpcUserFields.New', array($UserField), self::$_rpcMethods['New_']);
  }

  /**
   * Ruft die RPC-Funktion RpcUserFields.Put auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param GhRpcUserfieldslibRpcUserField $UserField
   */
  public function Put(GhRpcUserfieldslibRpcUserField $UserField)
  {
    return $this->_sendRpcRequest('RpcUserFields.Put', array($UserField), self::$_rpcMethods['Put']);
  }

  /**
   * Ruft die RPC-Funktion RpcUserFields.Delete auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Delete($ID)
  {
    return $this->_sendRpcRequest('RpcUserFields.Delete', array($ID), self::$_rpcMethods['Delete']);
  }

  /**
   * Ruft die RPC-Funktion RpcUserFields.SetOrder auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   * @param int $Order
   */
  public function SetOrder($ID, $Order)
  {
    return $this->_sendRpcRequest('RpcUserFields.SetOrder', array($ID, $Order), self::$_rpcMethods['SetOrder']);
  }

  /**
   * Ruft die RPC-Funktion RpcUserFields.Lock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Lock($ID)
  {
    return $this->_sendRpcRequest('RpcUserFields.Lock', array($ID), self::$_rpcMethods['Lock']);
  }

  /**
   * Ruft die RPC-Funktion RpcUserFields.Unlock auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   */
  public function Unlock($ID)
  {
    return $this->_sendRpcRequest('RpcUserFields.Unlock', array($ID), self::$_rpcMethods['Unlock']);
  }

  /**
   * Ruft die RPC-Funktion RpcUserFields.GetLockData auf.
   *
   * @throws GhRpcConnectionException falls beim Senden der RPC-Anfrage ein Fehler auftrat
   * @throws GhRpcException falls beim Verarbeiten der RPC-Daten oder des Ergebnisses ein Fehler auftrat
   *
   * @param int $ID
   *
   * @return GhRpcUserfieldslibRpcLockData
   */
  public function GetLockData($ID)
  {
    return $this->_sendRpcRequest('RpcUserFields.GetLockData', array($ID), self::$_rpcMethods['GetLockData']);
  }
}
